/* AppWindow.c generated by valac 0.36.6, the Vala compiler
 * generated from AppWindow.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <time.h>
#include <gdk/gdk.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <cairo.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gee.h>


#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;
typedef struct _PageWindowPrivate PageWindowPrivate;

#define TYPE_PAGE (page_get_type ())
#define PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE, Page))
#define PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE, PageClass))
#define IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE))
#define IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE))
#define PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE, PageClass))

typedef struct _Page Page;
typedef struct _PageClass PageClass;

#define TYPE_FULLSCREEN_WINDOW (fullscreen_window_get_type ())
#define FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindow))
#define FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))
#define IS_FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FULLSCREEN_WINDOW))
#define IS_FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FULLSCREEN_WINDOW))
#define FULLSCREEN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))

typedef struct _FullscreenWindow FullscreenWindow;
typedef struct _FullscreenWindowClass FullscreenWindowClass;
typedef struct _FullscreenWindowPrivate FullscreenWindowPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;

#define TYPE_SINGLE_PHOTO_PAGE (single_photo_page_get_type ())
#define SINGLE_PHOTO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPage))
#define SINGLE_PHOTO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPageClass))
#define IS_SINGLE_PHOTO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SINGLE_PHOTO_PAGE))
#define IS_SINGLE_PHOTO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SINGLE_PHOTO_PAGE))
#define SINGLE_PHOTO_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPageClass))

typedef struct _SinglePhotoPage SinglePhotoPage;
typedef struct _SinglePhotoPageClass SinglePhotoPageClass;

#define TYPE_SLIDESHOW_PAGE (slideshow_page_get_type ())
#define SLIDESHOW_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SLIDESHOW_PAGE, SlideshowPage))
#define SLIDESHOW_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SLIDESHOW_PAGE, SlideshowPageClass))
#define IS_SLIDESHOW_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SLIDESHOW_PAGE))
#define IS_SLIDESHOW_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SLIDESHOW_PAGE))
#define SLIDESHOW_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SLIDESHOW_PAGE, SlideshowPageClass))

typedef struct _SlideshowPage SlideshowPage;
typedef struct _SlideshowPageClass SlideshowPageClass;

#define TYPE_APPLICATION (application_get_type ())
#define APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APPLICATION, Application))
#define APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APPLICATION, ApplicationClass))
#define IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APPLICATION))
#define IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APPLICATION))
#define APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APPLICATION, ApplicationClass))

typedef struct _Application Application;
typedef struct _ApplicationClass ApplicationClass;
#define _application_unref0(var) ((var == NULL) ? NULL : (var = (application_unref (var), NULL)))
typedef struct _AppWindowPrivate AppWindowPrivate;

#define TYPE_DIMENSIONS (dimensions_get_type ())
typedef struct _Dimensions Dimensions;

#define TYPE_COMMAND_MANAGER (command_manager_get_type ())
#define COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND_MANAGER, CommandManager))
#define COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND_MANAGER, CommandManagerClass))
#define IS_COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND_MANAGER))
#define IS_COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND_MANAGER))
#define COMMAND_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND_MANAGER, CommandManagerClass))

typedef struct _CommandManager CommandManager;
typedef struct _CommandManagerClass CommandManagerClass;

#define TYPE_LIBRARY_WINDOW (library_window_get_type ())
#define LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_WINDOW, LibraryWindow))
#define LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_WINDOW, LibraryWindowClass))
#define IS_LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_WINDOW))
#define IS_LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_WINDOW))
#define LIBRARY_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_WINDOW, LibraryWindowClass))

typedef struct _LibraryWindow LibraryWindow;
typedef struct _LibraryWindowClass LibraryWindowClass;

#define TYPE_DIRECT_WINDOW (direct_window_get_type ())
#define DIRECT_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DIRECT_WINDOW, DirectWindow))
#define DIRECT_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DIRECT_WINDOW, DirectWindowClass))
#define IS_DIRECT_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DIRECT_WINDOW))
#define IS_DIRECT_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DIRECT_WINDOW))
#define DIRECT_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DIRECT_WINDOW, DirectWindowClass))

typedef struct _DirectWindow DirectWindow;
typedef struct _DirectWindowClass DirectWindowClass;
#define _command_manager_unref0(var) ((var == NULL) ? NULL : (var = (command_manager_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_VIEW_COLLECTION (view_collection_get_type ())
#define VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_COLLECTION, ViewCollection))
#define VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_COLLECTION, ViewCollectionClass))
#define IS_VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_COLLECTION))
#define IS_VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_COLLECTION))
#define VIEW_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_COLLECTION, ViewCollectionClass))

typedef struct _ViewCollection ViewCollection;
typedef struct _ViewCollectionClass ViewCollectionClass;
#define _data_collection_unref0(var) ((var == NULL) ? NULL : (var = (data_collection_unref (var), NULL)))

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define TYPE_DATA_VIEW (data_view_get_type ())
#define DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_VIEW, DataView))
#define DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_VIEW, DataViewClass))
#define IS_DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_VIEW))
#define IS_DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_VIEW))
#define DATA_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_VIEW, DataViewClass))

typedef struct _DataView DataView;
typedef struct _DataViewClass DataViewClass;
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))

#define TYPE_CHECKERBOARD_PAGE (checkerboard_page_get_type ())
#define CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPage))
#define CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))
#define IS_CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_PAGE))
#define IS_CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_PAGE))
#define CHECKERBOARD_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))

typedef struct _CheckerboardPage CheckerboardPage;
typedef struct _CheckerboardPageClass CheckerboardPageClass;
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))

#define TYPE_COMMAND_DESCRIPTION (command_description_get_type ())
#define COMMAND_DESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND_DESCRIPTION, CommandDescription))
#define IS_COMMAND_DESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND_DESCRIPTION))
#define COMMAND_DESCRIPTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_COMMAND_DESCRIPTION, CommandDescriptionIface))

typedef struct _CommandDescription CommandDescription;
typedef struct _CommandDescriptionIface CommandDescriptionIface;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PageWindow {
	GtkApplicationWindow parent_instance;
	PageWindowPrivate * priv;
};

struct _PageWindowClass {
	GtkApplicationWindowClass parent_class;
	void (*switched_pages) (PageWindow* self, Page* old_page, Page* new_page);
	void (*set_current_page) (PageWindow* self, Page* page);
	void (*clear_current_page) (PageWindow* self);
};

struct _FullscreenWindow {
	PageWindow parent_instance;
	FullscreenWindowPrivate * priv;
};

struct _FullscreenWindowClass {
	PageWindowClass parent_class;
};

struct _FullscreenWindowPrivate {
	GtkOverlay* overlay;
	GtkToolbar* toolbar;
	GtkToolButton* close_button;
	GtkToggleToolButton* pin_button;
	gboolean is_toolbar_shown;
	gboolean waiting_for_invoke;
	time_t left_toolbar_time;
	gboolean switched_to;
	gboolean is_toolbar_dismissal_enabled;
};

struct _PageWindowPrivate {
	Page* current_page;
	gint busy_counter;
};

struct _Dimensions {
	gint width;
	gint height;
};

struct _AppWindow {
	PageWindow parent_instance;
	AppWindowPrivate * priv;
	gboolean maximized;
	Dimensions dimensions;
	gint pos_x;
	gint pos_y;
};

struct _AppWindowClass {
	PageWindowClass parent_class;
	void (*on_fullscreen) (AppWindow* self);
	gchar* (*get_app_role) (AppWindow* self);
	void (*on_quit) (AppWindow* self);
	void (*add_actions) (AppWindow* self);
	void (*update_common_action_availability) (AppWindow* self, Page* old_page, Page* new_page);
	void (*update_common_actions) (AppWindow* self, Page* page, gint selected_count, gint count);
};

typedef enum  {
	DATABASE_ERROR_ERROR,
	DATABASE_ERROR_BACKING,
	DATABASE_ERROR_MEMORY,
	DATABASE_ERROR_ABORT,
	DATABASE_ERROR_LIMITS,
	DATABASE_ERROR_TYPESPEC
} DatabaseError;
#define DATABASE_ERROR database_error_quark ()
struct _CommandDescriptionIface {
	GTypeInterface parent_iface;
	gchar* (*get_name) (CommandDescription* self);
	gchar* (*get_explanation) (CommandDescription* self);
};


static gpointer fullscreen_window_parent_class = NULL;
static gpointer page_window_parent_class = NULL;
static gpointer app_window_parent_class = NULL;
extern AppWindow* app_window_instance;
AppWindow* app_window_instance = NULL;
static FullscreenWindow* app_window_fullscreen_window;
static FullscreenWindow* app_window_fullscreen_window = NULL;
static CommandManager* app_window_command_manager;
static CommandManager* app_window_command_manager = NULL;

GType page_window_get_type (void) G_GNUC_CONST;
GType page_get_type (void) G_GNUC_CONST;
GType fullscreen_window_get_type (void) G_GNUC_CONST;
#define FULLSCREEN_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_FULLSCREEN_WINDOW, FullscreenWindowPrivate))
enum  {
	FULLSCREEN_WINDOW_DUMMY_PROPERTY
};
#define FULLSCREEN_WINDOW_TOOLBAR_INVOCATION_MSEC 250
#define FULLSCREEN_WINDOW_TOOLBAR_DISMISSAL_SEC 2
#define FULLSCREEN_WINDOW_TOOLBAR_CHECK_DISMISSAL_MSEC 500
static void fullscreen_window_on_close (FullscreenWindow* self);
static void _fullscreen_window_on_close_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
FullscreenWindow* fullscreen_window_new (Page* page);
FullscreenWindow* fullscreen_window_construct (GType object_type, Page* page);
PageWindow* page_window_construct (GType object_type);
void page_window_set_current_page (PageWindow* self, Page* page);
void application_set_accels_for_action (const gchar* action, gchar** accel, int accel_length1);
GType app_window_get_type (void) G_GNUC_CONST;
AppWindow* app_window_get_instance (void);
static void fullscreen_window_get_monitor_geometry (FullscreenWindow* self, GdkRectangle* result);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
gboolean configuration_facade_get_pin_toolbar_state (ConfigurationFacade* self);
void fullscreen_window_update_toolbar_dismissal (FullscreenWindow* self);
static void _fullscreen_window_update_toolbar_dismissal_gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self);
GtkToolbar* page_get_toolbar (Page* self);
#define RESOURCES_TRANSIENT_WINDOW_OPACITY 0.90
GType single_photo_page_get_type (void) G_GNUC_CONST;
GType slideshow_page_get_type (void) G_GNUC_CONST;
static void fullscreen_window_hide_toolbar (FullscreenWindow* self);
static void _fullscreen_window_hide_toolbar_slideshow_page_hide_toolbar (SlideshowPage* _sender, gpointer self);
void page_set_cursor_hide_time (Page* self, gint hide_time);
void page_start_cursor_hiding (Page* self);
static void fullscreen_window_invoke_toolbar (FullscreenWindow* self);
void fullscreen_window_disable_toolbar_dismissal (FullscreenWindow* self);
static gboolean fullscreen_window_real_configure_event (GtkWidget* base, GdkEventConfigure* event);
Page* page_window_get_current_page (PageWindow* self);
void page_switched_to (Page* self);
static gboolean fullscreen_window_real_key_press_event (GtkWidget* base, GdkEventKey* event);
void configuration_facade_set_pin_toolbar_state (ConfigurationFacade* self, gboolean state);
void app_window_end_fullscreen (AppWindow* self);
void fullscreen_window_close (FullscreenWindow* self);
static void fullscreen_window_real_destroy (GtkWidget* base);
void page_window_clear_current_page (PageWindow* self);
void page_stop_cursor_hiding (Page* self);
void page_switching_from (Page* self);
static gboolean fullscreen_window_real_delete_event (GtkWidget* base, GdkEventAny* event);
static gboolean fullscreen_window_real_motion_notify_event (GtkWidget* base, GdkEventMotion* event);
static gboolean fullscreen_window_is_pointer_in_toolbar (FullscreenWindow* self);
static gboolean fullscreen_window_on_check_toolbar_invocation (FullscreenWindow* self);
static gboolean _fullscreen_window_on_check_toolbar_invocation_gsource_func (gpointer self);
static gboolean fullscreen_window_on_check_toolbar_dismissal (FullscreenWindow* self);
static gboolean _fullscreen_window_on_check_toolbar_dismissal_gsource_func (gpointer self);
static void fullscreen_window_finalize (GObject * obj);
#define PAGE_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PAGE_WINDOW, PageWindowPrivate))
enum  {
	PAGE_WINDOW_DUMMY_PROPERTY
};
void page_window_switched_pages (PageWindow* self, Page* old_page, Page* new_page);
static void page_window_real_switched_pages (PageWindow* self, Page* old_page, Page* new_page);
gpointer application_ref (gpointer instance);
void application_unref (gpointer instance);
GParamSpec* param_spec_application (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_application (GValue* value, gpointer v_object);
void value_take_application (GValue* value, gpointer v_object);
gpointer value_get_application (const GValue* value);
GType application_get_type (void) G_GNUC_CONST;
Application* application_get_instance (void);
GtkApplication* application_get_system_app (Application* self);
static void page_window_real_set_current_page (PageWindow* self, Page* page);
void page_clear_container (Page* self);
void page_set_container (Page* self, GtkWindow* container);
static void page_window_real_clear_current_page (PageWindow* self);
static gboolean page_window_real_key_press_event (GtkWidget* base, GdkEventKey* event);
gboolean page_notify_app_key_pressed (Page* self, GdkEventKey* event);
static gboolean page_window_real_key_release_event (GtkWidget* base, GdkEventKey* event);
gboolean page_notify_app_key_released (Page* self, GdkEventKey* event);
static gboolean page_window_real_focus_in_event (GtkWidget* base, GdkEventFocus* event);
gboolean page_notify_app_focus_in (Page* self, GdkEventFocus* event);
static gboolean page_window_real_focus_out_event (GtkWidget* base, GdkEventFocus* event);
gboolean page_notify_app_focus_out (Page* self, GdkEventFocus* event);
static gboolean page_window_real_configure_event (GtkWidget* base, GdkEventConfigure* event);
gboolean page_notify_configure_event (Page* self, GdkEventConfigure* event);
void page_window_set_busy_cursor (PageWindow* self);
void spin_event_loop (void);
void page_window_set_normal_cursor (PageWindow* self);
static void page_window_finalize (GObject * obj);
GType dimensions_get_type (void) G_GNUC_CONST;
Dimensions* dimensions_dup (const Dimensions* self);
void dimensions_free (Dimensions* self);
enum  {
	APP_WINDOW_DUMMY_PROPERTY
};
gpointer command_manager_ref (gpointer instance);
void command_manager_unref (gpointer instance);
GParamSpec* param_spec_command_manager (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_command_manager (GValue* value, gpointer v_object);
void value_take_command_manager (GValue* value, gpointer v_object);
gpointer value_get_command_manager (const GValue* value);
GType command_manager_get_type (void) G_GNUC_CONST;
#define APP_WINDOW_DND_ICON_SCALE 128
void app_window_on_about (AppWindow* self);
static void _app_window_on_about_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
void app_window_on_quit (AppWindow* self);
static void _app_window_on_quit_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
void app_window_on_fullscreen (AppWindow* self);
static void _app_window_on_fullscreen_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void app_window_on_help_contents (AppWindow* self);
static void _app_window_on_help_contents_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void app_window_on_help_faq (AppWindow* self);
static void _app_window_on_help_faq_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void app_window_on_help_report_problem (AppWindow* self);
static void _app_window_on_help_report_problem_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void app_window_on_undo (AppWindow* self);
static void _app_window_on_undo_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void app_window_on_redo (AppWindow* self);
static void _app_window_on_redo_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
void app_window_on_jump_to_file (AppWindow* self);
static void _app_window_on_jump_to_file_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void app_window_on_select_all (AppWindow* self);
static void _app_window_on_select_all_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void app_window_on_select_none (AppWindow* self);
static void _app_window_on_select_none_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
AppWindow* app_window_construct (GType object_type);
#define RESOURCES_APP_TITLE "Shotwell"
GType library_window_get_type (void) G_GNUC_CONST;
void configuration_facade_get_library_window_state (ConfigurationFacade* self, gboolean* maximize, Dimensions* dimensions);
GType direct_window_get_type (void) G_GNUC_CONST;
void configuration_facade_get_direct_window_state (ConfigurationFacade* self, gboolean* maximize, Dimensions* dimensions);
#define COMMAND_MANAGER_DEFAULT_DEPTH 20
CommandManager* command_manager_new (gint depth);
CommandManager* command_manager_construct (GType object_type, gint depth);
static void app_window_on_command_manager_altered (AppWindow* self);
static void _app_window_on_command_manager_altered_command_manager_altered (CommandManager* _sender, gboolean can_undo, gboolean can_redo, gpointer self);
void app_window_add_actions (AppWindow* self);
#define RESOURCES_CUSTOM_CSS "LibraryWindow .pane-separator {\n" \
"               background-color: @borders;\n" \
"            }\n" \
"            SearchFilterToolbar {\n" \
"               border-width: 0 0 1px 0;\n" \
"               border-style: solid;\n" \
"               border-color: @borders;\n" \
"            }"
static void app_window_real_on_fullscreen (AppWindow* self);
gboolean app_window_has_instance (void);
FullscreenWindow* app_window_get_fullscreen (void);
GtkBuilder* app_window_create_builder (const gchar* glade_filename, void* user);
gchar* resources_get_ui (const gchar* filename);
void app_window_error_message (const gchar* message, GtkWindow* parent);
void app_window_error_message_with_title (const gchar* title, const gchar* message, GtkWindow* parent, gboolean should_escape);
gchar* build_alert_body_text (const gchar* primary_text, const gchar* secondary_text, gboolean should_escape);
gboolean app_window_negate_affirm_question (const gchar* message, const gchar* negative, const gchar* affirmative, const gchar* title, GtkWindow* parent);
GtkResponseType app_window_negate_affirm_cancel_question (const gchar* message, const gchar* negative, const gchar* affirmative, const gchar* title, GtkWindow* parent);
GtkResponseType app_window_affirm_cancel_question (const gchar* message, const gchar* affirmative, const gchar* title, GtkWindow* parent);
GtkResponseType app_window_negate_affirm_all_cancel_question (const gchar* message, const gchar* negative, const gchar* affirmative, const gchar* affirmative_all, const gchar* title, GtkWindow* parent);
GQuark database_error_quark (void);
void app_window_database_error (GError* err);
void app_window_panic (const gchar* msg);
void application_panic (Application* self);
gchar* app_window_get_app_role (AppWindow* self);
static gchar* app_window_real_get_app_role (AppWindow* self);
#define RESOURCES_APP_VERSION _VERSION
#define RESOURCES_COPYRIGHT _ ("Copyright 2016 Software Freedom Conservancy Inc.")
#define RESOURCES_HOME_URL "https://wiki.gnome.org/Apps/Shotwell"
#define RESOURCES_LICENSE "\n" \
"Shotwell is free software; you can redistribute it and/or modify it un" \
"der the \n" \
"terms of the GNU Lesser General Public License as published by the Fre" \
"e \n" \
"Software Foundation; either version 2.1 of the License, or (at your op" \
"tion) \n" \
"any later version.\n" \
"\n" \
"Shotwell is distributed in the hope that it will be useful, but WITHOU" \
"T \n" \
"ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or " \
"FITNESS\n" \
"FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License f" \
"or \n" \
"more details.\n" \
"\n" \
"You should have received a copy of the GNU Lesser General Public Licen" \
"se \n" \
"along with Shotwell; if not, write to the Free Software Foundation, In" \
"c., \n" \
"51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA\n"
GdkPixbuf* resources_get_icon (const gchar* name, gint scale);
#define RESOURCES_ICON_ABOUT_LOGO "about-aachen.jpg"
void resources_launch_help (GdkScreen* screen, const gchar* anchor, GError** error);
void app_window_show_uri (AppWindow* self, const gchar* url, GError** error);
#define RESOURCES_BUG_DB_URL "https://wiki.gnome.org/Apps/Shotwell/ReportingABug"
#define RESOURCES_FAQ_URL "https://wiki.gnome.org/Apps/Shotwell/FAQ"
static void app_window_real_on_quit (AppWindow* self);
void application_exit (Application* self);
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_data_collection (GValue* value, gpointer v_object);
void value_take_data_collection (GValue* value, gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType view_collection_get_type (void) G_GNUC_CONST;
ViewCollection* page_get_view (Page* self);
gint view_collection_get_selected_count (ViewCollection* self);
GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
GType data_view_get_type (void) G_GNUC_CONST;
DataView* view_collection_get_selected_at (ViewCollection* self, gint index);
DataSource* data_view_get_source (DataView* self);
void app_window_show_file_uri (AppWindow* self, GFile* file, GError** error);
GFile* media_source_get_master_file (MediaSource* self);
gchar* resources_jump_to_file_failed (GError* err);
static void app_window_real_destroy (GtkWidget* base);
gchar* get_nautilus_install_location (void);
void show_file_in_nautilus (const gchar* filename, GError** error);
void sys_show_uri (GdkScreen* screen, const gchar* uri, GError** error);
static void app_window_real_add_actions (AppWindow* self);
void app_window_go_fullscreen (AppWindow* self, Page* page);
void page_switching_to_fullscreen (Page* self, FullscreenWindow* fsw);
void page_returning_from_fullscreen (Page* self, FullscreenWindow* fsw);
GAction* app_window_get_common_action (AppWindow* self, const gchar* name);
void app_window_set_common_action_sensitive (AppWindow* self, const gchar* name, gboolean sensitive);
void app_window_set_common_action_important (AppWindow* self, const gchar* name, gboolean important);
void app_window_set_common_action_visible (AppWindow* self, const gchar* name, gboolean visible);
static void app_window_real_switched_pages (PageWindow* base, Page* old_page, Page* new_page);
void app_window_update_common_action_availability (AppWindow* self, Page* old_page, Page* new_page);
static void app_window_on_update_common_actions (AppWindow* self);
static void _app_window_on_update_common_actions_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self);
static void _app_window_on_update_common_actions_view_collection_selection_group_altered (ViewCollection* _sender, gpointer self);
static void _app_window_on_update_common_actions_view_collection_items_state_changed (ViewCollection* _sender, GeeIterable* changed, gpointer self);
void app_window_update_common_actions (AppWindow* self, Page* page, gint selected_count, gint count);
gint data_collection_get_count (DataCollection* self);
static void app_window_real_update_common_action_availability (AppWindow* self, Page* old_page, Page* new_page);
GType checkerboard_page_get_type (void) G_GNUC_CONST;
static void app_window_real_update_common_actions (AppWindow* self, Page* page, gint selected_count, gint count);
void app_window_decorate_undo_action (AppWindow* self);
void app_window_decorate_redo_action (AppWindow* self);
void app_window_update_menu_item_label (AppWindow* self, const gchar* id, const gchar* new_label);
GMenuModel* page_get_menubar (Page* self);
CommandManager* app_window_get_command_manager (void);
GType command_description_get_type (void) G_GNUC_CONST;
static void app_window_decorate_command_manager_action (AppWindow* self, const gchar* name, const gchar* prefix, const gchar* default_explanation, CommandDescription* desc);
gchar* command_description_get_name (CommandDescription* self);
#define RESOURCES_UNDO_MENU _ ("_Undo")
CommandDescription* command_manager_get_undo_description (CommandManager* self);
#define RESOURCES_REDO_MENU _ ("_Redo")
CommandDescription* command_manager_get_redo_description (CommandManager* self);
gboolean command_manager_undo (CommandManager* self);
gboolean command_manager_redo (CommandManager* self);
void view_collection_select_all (ViewCollection* self);
void view_collection_unselect_all (ViewCollection* self);
static gboolean app_window_real_configure_event (GtkWidget* base, GdkEventConfigure* event);
static void app_window_finalize (GObject * obj);

static const GActionEntry FULLSCREEN_WINDOW_entries[1] = {{"LeaveFullscreen", _fullscreen_window_on_close_gsimple_action_activate_callback}};
static const GActionEntry APP_WINDOW_common_actions[11] = {{"CommonAbout", _app_window_on_about_gsimple_action_activate_callback}, {"CommonQuit", _app_window_on_quit_gsimple_action_activate_callback}, {"CommonFullscreen", _app_window_on_fullscreen_gsimple_action_activate_callback}, {"CommonHelpContents", _app_window_on_help_contents_gsimple_action_activate_callback}, {"CommonHelpFAQ", _app_window_on_help_faq_gsimple_action_activate_callback}, {"CommonHelpReportProblem", _app_window_on_help_report_problem_gsimple_action_activate_callback}, {"CommonUndo", _app_window_on_undo_gsimple_action_activate_callback}, {"CommonRedo", _app_window_on_redo_gsimple_action_activate_callback}, {"CommonJumpToFile", _app_window_on_jump_to_file_gsimple_action_activate_callback}, {"CommonSelectAll", _app_window_on_select_all_gsimple_action_activate_callback}, {"CommonSelectNone", _app_window_on_select_none_gsimple_action_activate_callback}};
extern const gchar* RESOURCES_AUTHORS[6];

static void _fullscreen_window_on_close_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 22 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_on_close ((FullscreenWindow*) self);
#line 577 "AppWindow.c"
}


static void _fullscreen_window_update_toolbar_dismissal_gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self) {
#line 50 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_update_toolbar_dismissal ((FullscreenWindow*) self);
#line 584 "AppWindow.c"
}


static void _fullscreen_window_hide_toolbar_slideshow_page_hide_toolbar (SlideshowPage* _sender, gpointer self) {
#line 65 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_hide_toolbar ((FullscreenWindow*) self);
#line 591 "AppWindow.c"
}


FullscreenWindow* fullscreen_window_construct (GType object_type, Page* page) {
	FullscreenWindow * self = NULL;
	Page* _tmp0_;
#line 32 "/home/jens/Source/shotwell/src/AppWindow.vala"
	static const gchar* accels[] = {"F11", NULL};
#line 600 "AppWindow.c"
	AppWindow* _tmp1_;
	AppWindow* _tmp2_;
	GdkScreen* _tmp3_;
	GdkRectangle monitor = {0};
	GdkRectangle _tmp4_ = {0};
	GdkRectangle _tmp5_;
	gint _tmp6_;
	GdkRectangle _tmp7_;
	gint _tmp8_;
	ConfigFacade* _tmp9_;
	ConfigFacade* _tmp10_;
	gboolean _tmp11_;
	GtkToggleToolButton* _tmp12_;
	GtkToggleToolButton* _tmp13_;
	GtkToggleToolButton* _tmp14_;
	GtkToggleToolButton* _tmp15_;
	gboolean _tmp16_;
	GtkToggleToolButton* _tmp17_;
	GtkToolButton* _tmp18_;
	GtkToolButton* _tmp19_;
	GtkToolButton* _tmp20_;
	Page* _tmp21_;
	GtkToolbar* _tmp22_;
	GtkToolbar* _tmp23_;
	GtkToolbar* _tmp24_;
	GtkToolbar* _tmp25_;
	GtkToolbar* _tmp26_;
	GtkToolbar* _tmp27_;
	Page* _tmp28_;
	Page* _tmp32_;
	Page* _tmp33_;
	GtkToolbar* _tmp34_;
	GtkToolButton* _tmp35_;
	GtkOverlay* _tmp36_;
	GtkOverlay* _tmp37_;
	Page* _tmp38_;
	GtkOverlay* _tmp39_;
	GtkToolbar* _tmp40_;
	GdkRectangle _tmp41_;
	gint _tmp42_;
	GdkRectangle _tmp43_;
	gint _tmp44_;
	Page* _tmp45_;
#line 26 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (IS_PAGE (page), NULL);
#line 27 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = (FullscreenWindow*) page_window_construct (object_type);
#line 29 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = page;
#line 29 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_window_set_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow), _tmp0_);
#line 31 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_action_map_add_action_entries (G_TYPE_CHECK_INSTANCE_CAST (self, g_action_map_get_type (), GActionMap), FULLSCREEN_WINDOW_entries, G_N_ELEMENTS (FULLSCREEN_WINDOW_entries), self);
#line 33 "/home/jens/Source/shotwell/src/AppWindow.vala"
	application_set_accels_for_action ("win.LeaveFullscreen", accels, G_N_ELEMENTS (accels));
#line 35 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = app_window_get_instance ();
#line 35 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = _tmp1_;
#line 35 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = gtk_window_get_screen (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_window_get_type (), GtkWindow));
#line 35 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_screen (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp3_);
#line 35 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp2_);
#line 38 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_get_monitor_geometry (self, &_tmp4_);
#line 38 "/home/jens/Source/shotwell/src/AppWindow.vala"
	monitor = _tmp4_;
#line 39 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = monitor;
#line 39 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = _tmp5_.x;
#line 39 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = monitor;
#line 39 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = _tmp7_.y;
#line 39 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_move (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp6_, _tmp8_);
#line 41 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_container_get_type (), GtkContainer), (guint) 0);
#line 44 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp9_ = config_facade_get_instance ();
#line 44 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = _tmp9_;
#line 44 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp11_ = configuration_facade_get_pin_toolbar_state (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 44 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->is_toolbar_dismissal_enabled = _tmp11_;
#line 44 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp10_);
#line 46 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp12_ = self->priv->pin_button;
#line 46 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_tool_button_set_icon_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_tool_button_get_type (), GtkToolButton), "pin-toolbar");
#line 47 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp13_ = self->priv->pin_button;
#line 47 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_tool_button_set_label (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_tool_button_get_type (), GtkToolButton), _ ("Pin Toolbar"));
#line 48 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp14_ = self->priv->pin_button;
#line 48 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_tool_item_set_tooltip_text (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_tool_item_get_type (), GtkToolItem), _ ("Pin the toolbar open"));
#line 49 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp15_ = self->priv->pin_button;
#line 49 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp16_ = self->priv->is_toolbar_dismissal_enabled;
#line 49 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_toggle_tool_button_set_active (_tmp15_, !_tmp16_);
#line 50 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp17_ = self->priv->pin_button;
#line 50 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_tool_button_get_type (), GtkToolButton), "clicked", (GCallback) _fullscreen_window_update_toolbar_dismissal_gtk_tool_button_clicked, self, 0);
#line 52 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp18_ = self->priv->close_button;
#line 52 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_tool_button_set_icon_name (_tmp18_, "view-restore");
#line 53 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp19_ = self->priv->close_button;
#line 53 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_tool_item_set_tooltip_text (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_tool_item_get_type (), GtkToolItem), _ ("Leave fullscreen"));
#line 54 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp20_ = self->priv->close_button;
#line 54 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_actionable_set_action_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GTK_TYPE_ACTIONABLE, GtkActionable), "win.LeaveFullscreen");
#line 56 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp21_ = page;
#line 56 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp22_ = page_get_toolbar (_tmp21_);
#line 56 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->toolbar);
#line 56 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->toolbar = _tmp22_;
#line 57 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp23_ = self->priv->toolbar;
#line 57 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_toolbar_set_show_arrow (_tmp23_, FALSE);
#line 58 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp24_ = self->priv->toolbar;
#line 58 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_END);
#line 59 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp25_ = self->priv->toolbar;
#line 59 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_CENTER);
#line 60 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp26_ = self->priv->toolbar;
#line 60 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_widget_get_type (), GtkWidget), "expand", FALSE, NULL);
#line 61 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp27_ = self->priv->toolbar;
#line 61 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_set_opacity (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_widget_get_type (), GtkWidget), RESOURCES_TRANSIENT_WINDOW_OPACITY);
#line 63 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp28_ = page;
#line 63 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, TYPE_SLIDESHOW_PAGE)) {
#line 758 "AppWindow.c"
		Page* _tmp29_;
#line 65 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp29_ = page;
#line 65 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, TYPE_SLIDESHOW_PAGE, SlideshowPage), "hide-toolbar", (GCallback) _fullscreen_window_hide_toolbar_slideshow_page_hide_toolbar, self, 0);
#line 764 "AppWindow.c"
	} else {
		GtkToolbar* _tmp30_;
		GtkToggleToolButton* _tmp31_;
#line 68 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp30_ = self->priv->toolbar;
#line 68 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp31_ = self->priv->pin_button;
#line 68 "/home/jens/Source/shotwell/src/AppWindow.vala"
		gtk_toolbar_insert (_tmp30_, G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, gtk_tool_item_get_type (), GtkToolItem), -1);
#line 774 "AppWindow.c"
	}
#line 71 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp32_ = page;
#line 71 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_set_cursor_hide_time (_tmp32_, FULLSCREEN_WINDOW_TOOLBAR_DISMISSAL_SEC * 1000);
#line 72 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp33_ = page;
#line 72 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_start_cursor_hiding (_tmp33_);
#line 74 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp34_ = self->priv->toolbar;
#line 74 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp35_ = self->priv->close_button;
#line 74 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_toolbar_insert (_tmp34_, G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, gtk_tool_item_get_type (), GtkToolItem), -1);
#line 76 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp36_ = self->priv->overlay;
#line 76 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, gtk_widget_get_type (), GtkWidget));
#line 77 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp37_ = self->priv->overlay;
#line 77 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp38_ = page;
#line 77 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, gtk_widget_get_type (), GtkWidget));
#line 78 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp39_ = self->priv->overlay;
#line 78 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp40_ = self->priv->toolbar;
#line 78 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_overlay_add_overlay (_tmp39_, G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, gtk_widget_get_type (), GtkWidget));
#line 83 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp41_ = monitor;
#line 83 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp42_ = _tmp41_.width;
#line 83 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp43_ = monitor;
#line 83 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp44_ = _tmp43_.height;
#line 83 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_default_size (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp42_, _tmp44_);
#line 86 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_fullscreen (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 87 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 90 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_add_events (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), (gint) GDK_POINTER_MOTION_MASK);
#line 93 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_invoke_toolbar (self);
#line 96 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp45_ = page;
#line 96 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, gtk_widget_get_type (), GtkWidget));
#line 99 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_application_window_set_show_menubar (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_window_get_type (), GtkApplicationWindow), FALSE);
#line 26 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return self;
#line 832 "AppWindow.c"
}


FullscreenWindow* fullscreen_window_new (Page* page) {
#line 26 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return fullscreen_window_construct (TYPE_FULLSCREEN_WINDOW, page);
#line 839 "AppWindow.c"
}


void fullscreen_window_disable_toolbar_dismissal (FullscreenWindow* self) {
#line 102 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (self));
#line 103 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->is_toolbar_dismissal_enabled = FALSE;
#line 848 "AppWindow.c"
}


void fullscreen_window_update_toolbar_dismissal (FullscreenWindow* self) {
	GtkToggleToolButton* _tmp0_;
	gboolean _tmp1_;
#line 106 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (self));
#line 107 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->pin_button;
#line 107 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gtk_toggle_tool_button_get_active (_tmp0_);
#line 107 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->is_toolbar_dismissal_enabled = !_tmp1_;
#line 863 "AppWindow.c"
}


static void fullscreen_window_get_monitor_geometry (FullscreenWindow* self, GdkRectangle* result) {
	GdkRectangle monitor = {0};
	GdkScreen* _tmp0_;
	GdkScreen* _tmp1_;
	AppWindow* _tmp2_;
	AppWindow* _tmp3_;
	GdkWindow* _tmp4_;
	gint _tmp5_;
	GdkRectangle _tmp6_ = {0};
#line 110 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (self));
#line 113 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = gtk_window_get_screen (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 113 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gtk_window_get_screen (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 113 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = app_window_get_instance ();
#line 113 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _tmp2_;
#line 113 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget));
#line 113 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = gdk_screen_get_monitor_at_window (_tmp1_, _tmp4_);
#line 113 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gdk_screen_get_monitor_geometry (_tmp0_, _tmp5_, &_tmp6_);
#line 113 "/home/jens/Source/shotwell/src/AppWindow.vala"
	monitor = _tmp6_;
#line 113 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp3_);
#line 116 "/home/jens/Source/shotwell/src/AppWindow.vala"
	*result = monitor;
#line 116 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return;
#line 900 "AppWindow.c"
}


static gboolean fullscreen_window_real_configure_event (GtkWidget* base, GdkEventConfigure* event) {
	FullscreenWindow * self;
	gboolean result = FALSE;
	gboolean _result_ = FALSE;
	GdkEventConfigure* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 119 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FULLSCREEN_WINDOW, FullscreenWindow);
#line 119 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 120 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = event;
#line 120 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = GTK_WIDGET_CLASS (fullscreen_window_parent_class)->configure_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow), gtk_widget_get_type (), GtkWidget), _tmp0_);
#line 120 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_result_ = _tmp1_;
#line 122 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = self->priv->switched_to;
#line 122 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (!_tmp2_) {
#line 925 "AppWindow.c"
		Page* _tmp3_;
		Page* _tmp4_;
#line 123 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 123 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = _tmp3_;
#line 123 "/home/jens/Source/shotwell/src/AppWindow.vala"
		page_switched_to (_tmp4_);
#line 123 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp4_);
#line 124 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->priv->switched_to = TRUE;
#line 938 "AppWindow.c"
	}
#line 127 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _result_;
#line 127 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 944 "AppWindow.c"
}


static gboolean fullscreen_window_real_key_press_event (GtkWidget* base, GdkEventKey* event) {
	FullscreenWindow * self;
	gboolean result = FALSE;
	GdkEventKey* _tmp0_;
	guint _tmp1_;
	const gchar* _tmp2_;
	gboolean _tmp3_ = FALSE;
	AppWindow* _tmp6_;
	AppWindow* _tmp7_;
	GdkEventKey* _tmp8_;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp10_;
#line 130 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FULLSCREEN_WINDOW, FullscreenWindow);
#line 130 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 132 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = event;
#line 132 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_->keyval;
#line 132 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = gdk_keyval_name (_tmp1_);
#line 132 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (g_strcmp0 (_tmp2_, "Escape") == 0) {
#line 133 "/home/jens/Source/shotwell/src/AppWindow.vala"
		fullscreen_window_on_close (self);
#line 135 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 135 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 978 "AppWindow.c"
	}
#line 139 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (GTK_WIDGET_CLASS (fullscreen_window_parent_class)->key_press_event != NULL) {
#line 982 "AppWindow.c"
		GdkEventKey* _tmp4_;
		gboolean _tmp5_;
#line 139 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = event;
#line 139 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = GTK_WIDGET_CLASS (fullscreen_window_parent_class)->key_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow), gtk_widget_get_type (), GtkWidget), _tmp4_);
#line 139 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = _tmp5_;
#line 991 "AppWindow.c"
	} else {
#line 139 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = FALSE;
#line 995 "AppWindow.c"
	}
#line 139 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp3_) {
#line 140 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 140 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1003 "AppWindow.c"
	}
#line 143 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = app_window_get_instance ();
#line 143 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = _tmp6_;
#line 143 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = event;
#line 143 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget), "key-press-event", _tmp8_, &_tmp9_);
#line 143 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = _tmp9_;
#line 143 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp7_);
#line 143 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp10_;
#line 143 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1021 "AppWindow.c"
}


static void fullscreen_window_on_close (FullscreenWindow* self) {
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	gboolean _tmp2_;
	AppWindow* _tmp3_;
	AppWindow* _tmp4_;
#line 146 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (self));
#line 147 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = config_facade_get_instance ();
#line 147 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 147 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = self->priv->is_toolbar_dismissal_enabled;
#line 147 "/home/jens/Source/shotwell/src/AppWindow.vala"
	configuration_facade_set_pin_toolbar_state (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_);
#line 147 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 148 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_hide_toolbar (self);
#line 150 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = app_window_get_instance ();
#line 150 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = _tmp3_;
#line 150 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_end_fullscreen (_tmp4_);
#line 150 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp4_);
#line 1053 "AppWindow.c"
}


void fullscreen_window_close (FullscreenWindow* self) {
#line 153 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (self));
#line 154 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_on_close (self);
#line 1062 "AppWindow.c"
}


static void fullscreen_window_real_destroy (GtkWidget* base) {
	FullscreenWindow * self;
	Page* page = NULL;
	Page* _tmp0_;
	Page* _tmp1_;
#line 157 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FULLSCREEN_WINDOW, FullscreenWindow);
#line 158 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 158 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page = _tmp0_;
#line 159 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_window_clear_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 161 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = page;
#line 161 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ != NULL) {
#line 1083 "AppWindow.c"
		Page* _tmp2_;
		Page* _tmp3_;
#line 162 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = page;
#line 162 "/home/jens/Source/shotwell/src/AppWindow.vala"
		page_stop_cursor_hiding (_tmp2_);
#line 163 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = page;
#line 163 "/home/jens/Source/shotwell/src/AppWindow.vala"
		page_switching_from (_tmp3_);
#line 1094 "AppWindow.c"
	}
#line 166 "/home/jens/Source/shotwell/src/AppWindow.vala"
	GTK_WIDGET_CLASS (fullscreen_window_parent_class)->destroy (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow), gtk_widget_get_type (), GtkWidget));
#line 157 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (page);
#line 1100 "AppWindow.c"
}


static gboolean fullscreen_window_real_delete_event (GtkWidget* base, GdkEventAny* event) {
	FullscreenWindow * self;
	gboolean result = FALSE;
	AppWindow* _tmp0_;
	AppWindow* _tmp1_;
#line 169 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FULLSCREEN_WINDOW, FullscreenWindow);
#line 169 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 170 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_on_close (self);
#line 171 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_get_instance ();
#line 171 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 171 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 171 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 173 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = TRUE;
#line 173 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1127 "AppWindow.c"
}


static gboolean _fullscreen_window_on_check_toolbar_invocation_gsource_func (gpointer self) {
	gboolean result;
	result = fullscreen_window_on_check_toolbar_invocation ((FullscreenWindow*) self);
#line 182 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1136 "AppWindow.c"
}


static gboolean fullscreen_window_real_motion_notify_event (GtkWidget* base, GdkEventMotion* event) {
	FullscreenWindow * self;
	gboolean result = FALSE;
	gboolean _tmp0_;
	gboolean _tmp4_ = FALSE;
#line 176 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FULLSCREEN_WINDOW, FullscreenWindow);
#line 176 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 177 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->is_toolbar_shown;
#line 177 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (!_tmp0_) {
#line 1153 "AppWindow.c"
		gboolean _tmp1_ = FALSE;
		gboolean _tmp2_;
#line 181 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = self->priv->waiting_for_invoke;
#line 181 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (!_tmp2_) {
#line 1160 "AppWindow.c"
			gboolean _tmp3_;
#line 181 "/home/jens/Source/shotwell/src/AppWindow.vala"
			_tmp3_ = fullscreen_window_is_pointer_in_toolbar (self);
#line 181 "/home/jens/Source/shotwell/src/AppWindow.vala"
			_tmp1_ = _tmp3_;
#line 1166 "AppWindow.c"
		} else {
#line 181 "/home/jens/Source/shotwell/src/AppWindow.vala"
			_tmp1_ = FALSE;
#line 1170 "AppWindow.c"
		}
#line 181 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (_tmp1_) {
#line 182 "/home/jens/Source/shotwell/src/AppWindow.vala"
			g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) FULLSCREEN_WINDOW_TOOLBAR_INVOCATION_MSEC, _fullscreen_window_on_check_toolbar_invocation_gsource_func, g_object_ref (self), g_object_unref);
#line 183 "/home/jens/Source/shotwell/src/AppWindow.vala"
			self->priv->waiting_for_invoke = TRUE;
#line 1178 "AppWindow.c"
		}
	}
#line 187 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (GTK_WIDGET_CLASS (fullscreen_window_parent_class)->motion_notify_event != NULL) {
#line 1183 "AppWindow.c"
		GdkEventMotion* _tmp5_;
		gboolean _tmp6_;
#line 187 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = event;
#line 187 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = GTK_WIDGET_CLASS (fullscreen_window_parent_class)->motion_notify_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow), gtk_widget_get_type (), GtkWidget), _tmp5_);
#line 187 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = _tmp6_;
#line 1192 "AppWindow.c"
	} else {
#line 187 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = FALSE;
#line 1196 "AppWindow.c"
	}
#line 187 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp4_;
#line 187 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1202 "AppWindow.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 191 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return self ? g_object_ref (self) : NULL;
#line 1209 "AppWindow.c"
}


static gboolean fullscreen_window_is_pointer_in_toolbar (FullscreenWindow* self) {
	gboolean result = FALSE;
	GdkDeviceManager* devmgr = NULL;
	GdkDisplay* _tmp0_;
	GdkDeviceManager* _tmp1_;
	GdkDeviceManager* _tmp2_;
	GdkDeviceManager* _tmp3_;
	gint py = 0;
	GdkDeviceManager* _tmp4_;
	GdkDevice* _tmp5_;
	gint _tmp6_ = 0;
	gint wy = 0;
	GtkToolbar* _tmp7_;
	GdkWindow* _tmp8_;
	gint _tmp9_ = 0;
	gint _tmp10_;
	gint _tmp11_;
#line 190 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (IS_FULLSCREEN_WINDOW (self), FALSE);
#line 191 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = gtk_widget_get_display (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 191 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gdk_display_get_device_manager (_tmp0_);
#line 191 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 191 "/home/jens/Source/shotwell/src/AppWindow.vala"
	devmgr = _tmp2_;
#line 192 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = devmgr;
#line 192 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp3_ == NULL) {
#line 193 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_debug ("AppWindow.vala:193: No device manager for display");
#line 195 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = FALSE;
#line 195 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (devmgr);
#line 195 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1252 "AppWindow.c"
	}
#line 199 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = devmgr;
#line 199 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = gdk_device_manager_get_client_pointer (_tmp4_);
#line 199 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gdk_device_get_position (_tmp5_, NULL, NULL, &_tmp6_);
#line 199 "/home/jens/Source/shotwell/src/AppWindow.vala"
	py = _tmp6_;
#line 202 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = self->priv->toolbar;
#line 202 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget));
#line 202 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gdk_window_get_geometry (_tmp8_, NULL, &_tmp9_, NULL, NULL);
#line 202 "/home/jens/Source/shotwell/src/AppWindow.vala"
	wy = _tmp9_;
#line 204 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = py;
#line 204 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp11_ = wy;
#line 204 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp10_ >= _tmp11_;
#line 204 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (devmgr);
#line 204 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1280 "AppWindow.c"
}


static gboolean fullscreen_window_on_check_toolbar_invocation (FullscreenWindow* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
	gboolean _tmp1_;
#line 207 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (IS_FULLSCREEN_WINDOW (self), FALSE);
#line 208 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->waiting_for_invoke = FALSE;
#line 210 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->is_toolbar_shown;
#line 210 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_) {
#line 211 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = FALSE;
#line 211 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1300 "AppWindow.c"
	}
#line 213 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = fullscreen_window_is_pointer_in_toolbar (self);
#line 213 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (!_tmp1_) {
#line 214 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = FALSE;
#line 214 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1310 "AppWindow.c"
	}
#line 216 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_invoke_toolbar (self);
#line 218 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = FALSE;
#line 218 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1318 "AppWindow.c"
}


static gboolean _fullscreen_window_on_check_toolbar_dismissal_gsource_func (gpointer self) {
	gboolean result;
	result = fullscreen_window_on_check_toolbar_dismissal ((FullscreenWindow*) self);
#line 226 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1327 "AppWindow.c"
}


static void fullscreen_window_invoke_toolbar (FullscreenWindow* self) {
	GtkToolbar* _tmp0_;
#line 221 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (self));
#line 222 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->toolbar;
#line 222 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 224 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->is_toolbar_shown = TRUE;
#line 226 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) FULLSCREEN_WINDOW_TOOLBAR_CHECK_DISMISSAL_MSEC, _fullscreen_window_on_check_toolbar_dismissal_gsource_func, g_object_ref (self), g_object_unref);
#line 1343 "AppWindow.c"
}


static gboolean fullscreen_window_on_check_toolbar_dismissal (FullscreenWindow* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	time_t _tmp3_;
	time_t now = 0;
	time_t _tmp5_;
	time_t _tmp6_;
	time_t _tmp7_;
	time_t _tmp8_;
	time_t _tmp9_;
#line 229 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (IS_FULLSCREEN_WINDOW (self), FALSE);
#line 230 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->is_toolbar_shown;
#line 230 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (!_tmp0_) {
#line 231 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = FALSE;
#line 231 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1369 "AppWindow.c"
	}
#line 234 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = self->priv->is_toolbar_dismissal_enabled;
#line 234 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (!_tmp1_) {
#line 235 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 235 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1379 "AppWindow.c"
	}
#line 238 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = fullscreen_window_is_pointer_in_toolbar (self);
#line 238 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_) {
#line 239 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->priv->left_toolbar_time = (time_t) 0;
#line 241 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 241 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1391 "AppWindow.c"
	}
#line 245 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = self->priv->left_toolbar_time;
#line 245 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp3_ == ((time_t) 0)) {
#line 1397 "AppWindow.c"
		time_t _tmp4_;
#line 246 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = time (NULL);
#line 246 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->priv->left_toolbar_time = _tmp4_;
#line 248 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 248 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1407 "AppWindow.c"
	}
#line 252 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = time (NULL);
#line 252 "/home/jens/Source/shotwell/src/AppWindow.vala"
	now = _tmp5_;
#line 253 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = now;
#line 253 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = self->priv->left_toolbar_time;
#line 253 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_vala_assert (_tmp6_ >= _tmp7_, "now >= left_toolbar_time");
#line 255 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = now;
#line 255 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp9_ = self->priv->left_toolbar_time;
#line 255 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if ((_tmp8_ - _tmp9_) < ((time_t) FULLSCREEN_WINDOW_TOOLBAR_DISMISSAL_SEC)) {
#line 256 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 256 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1429 "AppWindow.c"
	}
#line 258 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_hide_toolbar (self);
#line 260 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = FALSE;
#line 260 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1437 "AppWindow.c"
}


static void fullscreen_window_hide_toolbar (FullscreenWindow* self) {
	GtkToolbar* _tmp0_;
#line 263 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (self));
#line 264 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->toolbar;
#line 264 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 265 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->is_toolbar_shown = FALSE;
#line 1451 "AppWindow.c"
}


static void fullscreen_window_class_init (FullscreenWindowClass * klass) {
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fullscreen_window_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_type_class_add_private (klass, sizeof (FullscreenWindowPrivate));
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->configure_event = (gboolean (*) (GtkWidget *, GdkEventConfigure*)) fullscreen_window_real_configure_event;
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->key_press_event = (gboolean (*) (GtkWidget *, GdkEventKey*)) fullscreen_window_real_key_press_event;
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->destroy = (void (*) (GtkWidget *)) fullscreen_window_real_destroy;
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->delete_event = (gboolean (*) (GtkWidget *, GdkEventAny*)) fullscreen_window_real_delete_event;
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->motion_notify_event = (gboolean (*) (GtkWidget *, GdkEventMotion*)) fullscreen_window_real_motion_notify_event;
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	G_OBJECT_CLASS (klass)->finalize = fullscreen_window_finalize;
#line 1472 "AppWindow.c"
}


static void fullscreen_window_instance_init (FullscreenWindow * self) {
	GtkOverlay* _tmp0_;
	GtkToolButton* _tmp1_;
	GtkToggleToolButton* _tmp2_;
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv = FULLSCREEN_WINDOW_GET_PRIVATE (self);
#line 12 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = (GtkOverlay*) gtk_overlay_new ();
#line 12 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp0_);
#line 12 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->overlay = _tmp0_;
#line 13 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->toolbar = NULL;
#line 14 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = (GtkToolButton*) gtk_tool_button_new (NULL, NULL);
#line 14 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp1_);
#line 14 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->close_button = _tmp1_;
#line 15 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = (GtkToggleToolButton*) gtk_toggle_tool_button_new ();
#line 15 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp2_);
#line 15 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->pin_button = _tmp2_;
#line 16 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->is_toolbar_shown = FALSE;
#line 17 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->waiting_for_invoke = FALSE;
#line 18 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->left_toolbar_time = (time_t) 0;
#line 19 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->switched_to = FALSE;
#line 1510 "AppWindow.c"
}


static void fullscreen_window_finalize (GObject * obj) {
	FullscreenWindow * self;
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_FULLSCREEN_WINDOW, FullscreenWindow);
#line 12 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->overlay);
#line 13 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->toolbar);
#line 14 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->close_button);
#line 15 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->pin_button);
#line 7 "/home/jens/Source/shotwell/src/AppWindow.vala"
	G_OBJECT_CLASS (fullscreen_window_parent_class)->finalize (obj);
#line 1528 "AppWindow.c"
}


GType fullscreen_window_get_type (void) {
	static volatile gsize fullscreen_window_type_id__volatile = 0;
	if (g_once_init_enter (&fullscreen_window_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (FullscreenWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) fullscreen_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FullscreenWindow), 0, (GInstanceInitFunc) fullscreen_window_instance_init, NULL };
		GType fullscreen_window_type_id;
		fullscreen_window_type_id = g_type_register_static (TYPE_PAGE_WINDOW, "FullscreenWindow", &g_define_type_info, 0);
		g_once_init_leave (&fullscreen_window_type_id__volatile, fullscreen_window_type_id);
	}
	return fullscreen_window_type_id__volatile;
}


static void page_window_real_switched_pages (PageWindow* self, Page* old_page, Page* new_page) {
#line 280 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((old_page == NULL) || IS_PAGE (old_page));
#line 280 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((new_page == NULL) || IS_PAGE (new_page));
#line 1549 "AppWindow.c"
}


void page_window_switched_pages (PageWindow* self, Page* old_page, Page* new_page) {
#line 280 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE_WINDOW (self));
#line 280 "/home/jens/Source/shotwell/src/AppWindow.vala"
	PAGE_WINDOW_GET_CLASS (self)->switched_pages (self, old_page, new_page);
#line 1558 "AppWindow.c"
}


PageWindow* page_window_construct (GType object_type) {
	PageWindow * self = NULL;
	Application* _tmp0_;
	Application* _tmp1_;
	GtkApplication* _tmp2_;
	GtkApplication* _tmp3_;
#line 284 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = application_get_instance ();
#line 284 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 284 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = application_get_system_app (_tmp1_);
#line 284 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _tmp2_;
#line 284 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = (PageWindow*) g_object_new (object_type, "application", _tmp3_, NULL);
#line 284 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp3_);
#line 284 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_application_unref0 (_tmp1_);
#line 287 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_add_events (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), (gint) ((GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK) | GDK_STRUCTURE_MASK));
#line 289 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_application_window_set_show_menubar (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_window_get_type (), GtkApplicationWindow), TRUE);
#line 283 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return self;
#line 1588 "AppWindow.c"
}


Page* page_window_get_current_page (PageWindow* self) {
	Page* result = NULL;
	Page* _tmp0_;
	Page* _tmp1_;
#line 292 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (IS_PAGE_WINDOW (self), NULL);
#line 293 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->current_page;
#line 293 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 293 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp1_;
#line 293 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1606 "AppWindow.c"
}


static void page_window_real_set_current_page (PageWindow* self, Page* page) {
	Page* _tmp0_;
	Page* old_page = NULL;
	Page* _tmp2_;
	Page* _tmp3_;
	Page* _tmp4_;
	Page* _tmp5_;
	Page* _tmp6_;
	Page* _tmp7_;
#line 296 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 297 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->current_page;
#line 297 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_ != NULL) {
#line 1625 "AppWindow.c"
		Page* _tmp1_;
#line 298 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = self->priv->current_page;
#line 298 "/home/jens/Source/shotwell/src/AppWindow.vala"
		page_clear_container (_tmp1_);
#line 1631 "AppWindow.c"
	}
#line 300 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = self->priv->current_page;
#line 300 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 300 "/home/jens/Source/shotwell/src/AppWindow.vala"
	old_page = _tmp3_;
#line 301 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = page;
#line 301 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 301 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->current_page);
#line 301 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->current_page = _tmp5_;
#line 302 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = self->priv->current_page;
#line 302 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_set_container (_tmp6_, G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 304 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = page;
#line 304 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_window_switched_pages (self, old_page, _tmp7_);
#line 296 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (old_page);
#line 1657 "AppWindow.c"
}


void page_window_set_current_page (PageWindow* self, Page* page) {
#line 296 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE_WINDOW (self));
#line 296 "/home/jens/Source/shotwell/src/AppWindow.vala"
	PAGE_WINDOW_GET_CLASS (self)->set_current_page (self, page);
#line 1666 "AppWindow.c"
}


static void page_window_real_clear_current_page (PageWindow* self) {
	Page* _tmp0_;
	Page* old_page = NULL;
	Page* _tmp2_;
	Page* _tmp3_;
#line 308 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->current_page;
#line 308 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_ != NULL) {
#line 1679 "AppWindow.c"
		Page* _tmp1_;
#line 309 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = self->priv->current_page;
#line 309 "/home/jens/Source/shotwell/src/AppWindow.vala"
		page_clear_container (_tmp1_);
#line 1685 "AppWindow.c"
	}
#line 311 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = self->priv->current_page;
#line 311 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 311 "/home/jens/Source/shotwell/src/AppWindow.vala"
	old_page = _tmp3_;
#line 312 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->current_page);
#line 312 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->current_page = NULL;
#line 314 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_window_switched_pages (self, old_page, NULL);
#line 307 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (old_page);
#line 1701 "AppWindow.c"
}


void page_window_clear_current_page (PageWindow* self) {
#line 307 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE_WINDOW (self));
#line 307 "/home/jens/Source/shotwell/src/AppWindow.vala"
	PAGE_WINDOW_GET_CLASS (self)->clear_current_page (self);
#line 1710 "AppWindow.c"
}


static gboolean page_window_real_key_press_event (GtkWidget* base, GdkEventKey* event) {
	PageWindow * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	GtkWidget* _tmp1_;
	gboolean _tmp5_ = FALSE;
	Page* _tmp6_;
	gboolean _tmp10_ = FALSE;
#line 317 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PAGE_WINDOW, PageWindow);
#line 317 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 318 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gtk_window_get_focus (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 318 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_entry_get_type ())) {
#line 1730 "AppWindow.c"
		GtkWidget* _tmp2_;
		GdkEventKey* _tmp3_;
		gboolean _tmp4_ = FALSE;
#line 318 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = gtk_window_get_focus (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 318 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = event;
#line 318 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_emit_by_name (_tmp2_, "key-press-event", _tmp3_, &_tmp4_);
#line 318 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp4_;
#line 1742 "AppWindow.c"
	} else {
#line 318 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = FALSE;
#line 1746 "AppWindow.c"
	}
#line 318 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_) {
#line 319 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 319 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1754 "AppWindow.c"
	}
#line 321 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = self->priv->current_page;
#line 321 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp6_ != NULL) {
#line 1760 "AppWindow.c"
		Page* _tmp7_;
		GdkEventKey* _tmp8_;
		gboolean _tmp9_;
#line 321 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = self->priv->current_page;
#line 321 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp8_ = event;
#line 321 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp9_ = page_notify_app_key_pressed (_tmp7_, _tmp8_);
#line 321 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp9_;
#line 1772 "AppWindow.c"
	} else {
#line 321 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = FALSE;
#line 1776 "AppWindow.c"
	}
#line 321 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp5_) {
#line 322 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 322 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1784 "AppWindow.c"
	}
#line 324 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (GTK_WIDGET_CLASS (page_window_parent_class)->key_press_event != NULL) {
#line 1788 "AppWindow.c"
		GdkEventKey* _tmp11_;
		gboolean _tmp12_;
#line 324 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp11_ = event;
#line 324 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp12_ = GTK_WIDGET_CLASS (page_window_parent_class)->key_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_window_get_type (), GtkApplicationWindow), gtk_widget_get_type (), GtkWidget), _tmp11_);
#line 324 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp10_ = _tmp12_;
#line 1797 "AppWindow.c"
	} else {
#line 324 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp10_ = FALSE;
#line 1801 "AppWindow.c"
	}
#line 324 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp10_;
#line 324 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1807 "AppWindow.c"
}


static gboolean page_window_real_key_release_event (GtkWidget* base, GdkEventKey* event) {
	PageWindow * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	GtkWidget* _tmp1_;
	gboolean _tmp5_ = FALSE;
	Page* _tmp6_;
	gboolean _tmp10_ = FALSE;
#line 327 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PAGE_WINDOW, PageWindow);
#line 327 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 328 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gtk_window_get_focus (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 328 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_entry_get_type ())) {
#line 1827 "AppWindow.c"
		GtkWidget* _tmp2_;
		GdkEventKey* _tmp3_;
		gboolean _tmp4_ = FALSE;
#line 328 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = gtk_window_get_focus (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 328 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = event;
#line 328 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_emit_by_name (_tmp2_, "key-release-event", _tmp3_, &_tmp4_);
#line 328 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp4_;
#line 1839 "AppWindow.c"
	} else {
#line 328 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = FALSE;
#line 1843 "AppWindow.c"
	}
#line 328 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_) {
#line 329 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 329 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1851 "AppWindow.c"
	}
#line 331 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = self->priv->current_page;
#line 331 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp6_ != NULL) {
#line 1857 "AppWindow.c"
		Page* _tmp7_;
		GdkEventKey* _tmp8_;
		gboolean _tmp9_;
#line 331 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = self->priv->current_page;
#line 331 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp8_ = event;
#line 331 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp9_ = page_notify_app_key_released (_tmp7_, _tmp8_);
#line 331 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp9_;
#line 1869 "AppWindow.c"
	} else {
#line 331 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = FALSE;
#line 1873 "AppWindow.c"
	}
#line 331 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp5_) {
#line 332 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 332 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1881 "AppWindow.c"
	}
#line 334 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (GTK_WIDGET_CLASS (page_window_parent_class)->key_release_event != NULL) {
#line 1885 "AppWindow.c"
		GdkEventKey* _tmp11_;
		gboolean _tmp12_;
#line 334 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp11_ = event;
#line 334 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp12_ = GTK_WIDGET_CLASS (page_window_parent_class)->key_release_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_window_get_type (), GtkApplicationWindow), gtk_widget_get_type (), GtkWidget), _tmp11_);
#line 334 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp10_ = _tmp12_;
#line 1894 "AppWindow.c"
	} else {
#line 334 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp10_ = FALSE;
#line 1898 "AppWindow.c"
	}
#line 334 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp10_;
#line 334 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1904 "AppWindow.c"
}


static gboolean page_window_real_focus_in_event (GtkWidget* base, GdkEventFocus* event) {
	PageWindow * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	Page* _tmp1_;
	gboolean _tmp5_ = FALSE;
#line 337 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PAGE_WINDOW, PageWindow);
#line 337 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 338 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = self->priv->current_page;
#line 338 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ != NULL) {
#line 1922 "AppWindow.c"
		Page* _tmp2_;
		GdkEventFocus* _tmp3_;
		gboolean _tmp4_;
#line 338 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = self->priv->current_page;
#line 338 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = event;
#line 338 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = page_notify_app_focus_in (_tmp2_, _tmp3_);
#line 338 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp4_;
#line 1934 "AppWindow.c"
	} else {
#line 338 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = FALSE;
#line 1938 "AppWindow.c"
	}
#line 338 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_) {
#line 339 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 339 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 1946 "AppWindow.c"
	}
#line 341 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (GTK_WIDGET_CLASS (page_window_parent_class)->focus_in_event != NULL) {
#line 1950 "AppWindow.c"
		GdkEventFocus* _tmp6_;
		gboolean _tmp7_;
#line 341 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = event;
#line 341 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = GTK_WIDGET_CLASS (page_window_parent_class)->focus_in_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_window_get_type (), GtkApplicationWindow), gtk_widget_get_type (), GtkWidget), _tmp6_);
#line 341 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp7_;
#line 1959 "AppWindow.c"
	} else {
#line 341 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = FALSE;
#line 1963 "AppWindow.c"
	}
#line 341 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp5_;
#line 341 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 1969 "AppWindow.c"
}


static gboolean page_window_real_focus_out_event (GtkWidget* base, GdkEventFocus* event) {
	PageWindow * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	Page* _tmp1_;
	gboolean _tmp5_ = FALSE;
#line 344 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PAGE_WINDOW, PageWindow);
#line 344 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 345 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = self->priv->current_page;
#line 345 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ != NULL) {
#line 1987 "AppWindow.c"
		Page* _tmp2_;
		GdkEventFocus* _tmp3_;
		gboolean _tmp4_;
#line 345 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = self->priv->current_page;
#line 345 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = event;
#line 345 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = page_notify_app_focus_out (_tmp2_, _tmp3_);
#line 345 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp4_;
#line 1999 "AppWindow.c"
	} else {
#line 345 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = FALSE;
#line 2003 "AppWindow.c"
	}
#line 345 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_) {
#line 346 "/home/jens/Source/shotwell/src/AppWindow.vala"
		result = TRUE;
#line 346 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return result;
#line 2011 "AppWindow.c"
	}
#line 348 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (GTK_WIDGET_CLASS (page_window_parent_class)->focus_out_event != NULL) {
#line 2015 "AppWindow.c"
		GdkEventFocus* _tmp6_;
		gboolean _tmp7_;
#line 348 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = event;
#line 348 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = GTK_WIDGET_CLASS (page_window_parent_class)->focus_out_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_window_get_type (), GtkApplicationWindow), gtk_widget_get_type (), GtkWidget), _tmp6_);
#line 348 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp7_;
#line 2024 "AppWindow.c"
	} else {
#line 348 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = FALSE;
#line 2028 "AppWindow.c"
	}
#line 348 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp5_;
#line 348 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2034 "AppWindow.c"
}


static gboolean page_window_real_configure_event (GtkWidget* base, GdkEventConfigure* event) {
	PageWindow * self;
	gboolean result = FALSE;
	Page* _tmp0_;
	gboolean _tmp4_ = FALSE;
#line 351 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PAGE_WINDOW, PageWindow);
#line 351 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 352 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->current_page;
#line 352 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_ != NULL) {
#line 2051 "AppWindow.c"
		Page* _tmp1_;
		GdkEventConfigure* _tmp2_;
		gboolean _tmp3_;
#line 353 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = self->priv->current_page;
#line 353 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = event;
#line 353 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = page_notify_configure_event (_tmp1_, _tmp2_);
#line 353 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (_tmp3_) {
#line 354 "/home/jens/Source/shotwell/src/AppWindow.vala"
			result = TRUE;
#line 354 "/home/jens/Source/shotwell/src/AppWindow.vala"
			return result;
#line 2067 "AppWindow.c"
		}
	}
#line 357 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (GTK_WIDGET_CLASS (page_window_parent_class)->configure_event != NULL) {
#line 2072 "AppWindow.c"
		GdkEventConfigure* _tmp5_;
		gboolean _tmp6_;
#line 357 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = event;
#line 357 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = GTK_WIDGET_CLASS (page_window_parent_class)->configure_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_window_get_type (), GtkApplicationWindow), gtk_widget_get_type (), GtkWidget), _tmp5_);
#line 357 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = _tmp6_;
#line 2081 "AppWindow.c"
	} else {
#line 357 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = FALSE;
#line 2085 "AppWindow.c"
	}
#line 357 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp4_;
#line 357 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2091 "AppWindow.c"
}


void page_window_set_busy_cursor (PageWindow* self) {
	gint _tmp0_;
	GdkDisplay* display = NULL;
	GdkWindow* _tmp1_;
	GdkDisplay* _tmp2_;
	GdkDisplay* _tmp3_;
	GdkCursor* cursor = NULL;
	GdkDisplay* _tmp4_;
	GdkCursor* _tmp5_;
	GdkWindow* _tmp6_;
	GdkCursor* _tmp7_;
#line 360 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE_WINDOW (self));
#line 361 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->busy_counter;
#line 361 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->busy_counter = _tmp0_ + 1;
#line 361 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_ > 0) {
#line 362 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 2116 "AppWindow.c"
	}
#line 364 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 364 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = gdk_window_get_display (_tmp1_);
#line 364 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 364 "/home/jens/Source/shotwell/src/AppWindow.vala"
	display = _tmp3_;
#line 365 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = display;
#line 365 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = gdk_cursor_new_for_display (_tmp4_, GDK_WATCH);
#line 365 "/home/jens/Source/shotwell/src/AppWindow.vala"
	cursor = _tmp5_;
#line 366 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 366 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = cursor;
#line 366 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gdk_window_set_cursor (_tmp6_, _tmp7_);
#line 367 "/home/jens/Source/shotwell/src/AppWindow.vala"
	spin_event_loop ();
#line 360 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (cursor);
#line 360 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (display);
#line 2144 "AppWindow.c"
}


void page_window_set_normal_cursor (PageWindow* self) {
	gint _tmp0_;
	GdkDisplay* display = NULL;
	GdkWindow* _tmp3_;
	GdkDisplay* _tmp4_;
	GdkDisplay* _tmp5_;
	GdkCursor* cursor = NULL;
	GdkDisplay* _tmp6_;
	GdkCursor* _tmp7_;
	GdkWindow* _tmp8_;
	GdkCursor* _tmp9_;
#line 370 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE_WINDOW (self));
#line 371 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = self->priv->busy_counter;
#line 371 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_ <= 0) {
#line 372 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->priv->busy_counter = 0;
#line 373 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 2169 "AppWindow.c"
	} else {
		gint _tmp1_;
		gint _tmp2_;
#line 374 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = self->priv->busy_counter;
#line 374 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->priv->busy_counter = _tmp1_ - 1;
#line 374 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = self->priv->busy_counter;
#line 374 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (_tmp2_ > 0) {
#line 375 "/home/jens/Source/shotwell/src/AppWindow.vala"
			return;
#line 2183 "AppWindow.c"
		}
	}
#line 378 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 378 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = gdk_window_get_display (_tmp3_);
#line 378 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 378 "/home/jens/Source/shotwell/src/AppWindow.vala"
	display = _tmp5_;
#line 379 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = display;
#line 379 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = gdk_cursor_new_for_display (_tmp6_, GDK_LEFT_PTR);
#line 379 "/home/jens/Source/shotwell/src/AppWindow.vala"
	cursor = _tmp7_;
#line 380 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 380 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp9_ = cursor;
#line 380 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gdk_window_set_cursor (_tmp8_, _tmp9_);
#line 381 "/home/jens/Source/shotwell/src/AppWindow.vala"
	spin_event_loop ();
#line 370 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (cursor);
#line 370 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (display);
#line 2212 "AppWindow.c"
}


static void page_window_class_init (PageWindowClass * klass) {
#line 276 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page_window_parent_class = g_type_class_peek_parent (klass);
#line 276 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_type_class_add_private (klass, sizeof (PageWindowPrivate));
#line 276 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((PageWindowClass *) klass)->switched_pages = (void (*) (PageWindow *, Page*, Page*)) page_window_real_switched_pages;
#line 276 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((PageWindowClass *) klass)->set_current_page = (void (*) (PageWindow *, Page*)) page_window_real_set_current_page;
#line 276 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((PageWindowClass *) klass)->clear_current_page = (void (*) (PageWindow *)) page_window_real_clear_current_page;
#line 276 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->key_press_event = (gboolean (*) (GtkWidget *, GdkEventKey*)) page_window_real_key_press_event;
#line 276 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->key_release_event = (gboolean (*) (GtkWidget *, GdkEventKey*)) page_window_real_key_release_event;
#line 276 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->focus_in_event = (gboolean (*) (GtkWidget *, GdkEventFocus*)) page_window_real_focus_in_event;
#line 276 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->focus_out_event = (gboolean (*) (GtkWidget *, GdkEventFocus*)) page_window_real_focus_out_event;
#line 276 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->configure_event = (gboolean (*) (GtkWidget *, GdkEventConfigure*)) page_window_real_configure_event;
#line 276 "/home/jens/Source/shotwell/src/AppWindow.vala"
	G_OBJECT_CLASS (klass)->finalize = page_window_finalize;
#line 2239 "AppWindow.c"
}


static void page_window_instance_init (PageWindow * self) {
#line 276 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv = PAGE_WINDOW_GET_PRIVATE (self);
#line 277 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->current_page = NULL;
#line 278 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->priv->busy_counter = 0;
#line 2250 "AppWindow.c"
}


static void page_window_finalize (GObject * obj) {
	PageWindow * self;
#line 276 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PAGE_WINDOW, PageWindow);
#line 277 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (self->priv->current_page);
#line 276 "/home/jens/Source/shotwell/src/AppWindow.vala"
	G_OBJECT_CLASS (page_window_parent_class)->finalize (obj);
#line 2262 "AppWindow.c"
}


GType page_window_get_type (void) {
	static volatile gsize page_window_type_id__volatile = 0;
	if (g_once_init_enter (&page_window_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PageWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) page_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PageWindow), 0, (GInstanceInitFunc) page_window_instance_init, NULL };
		GType page_window_type_id;
		page_window_type_id = g_type_register_static (gtk_application_window_get_type (), "PageWindow", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&page_window_type_id__volatile, page_window_type_id);
	}
	return page_window_type_id__volatile;
}


static void _app_window_on_about_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 449 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_about ((AppWindow*) self);
#line 2281 "AppWindow.c"
}


static void _app_window_on_quit_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 449 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_quit ((AppWindow*) self);
#line 2288 "AppWindow.c"
}


static void _app_window_on_fullscreen_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 449 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_fullscreen ((AppWindow*) self);
#line 2295 "AppWindow.c"
}


static void _app_window_on_help_contents_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 449 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_help_contents ((AppWindow*) self);
#line 2302 "AppWindow.c"
}


static void _app_window_on_help_faq_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 449 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_help_faq ((AppWindow*) self);
#line 2309 "AppWindow.c"
}


static void _app_window_on_help_report_problem_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 449 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_help_report_problem ((AppWindow*) self);
#line 2316 "AppWindow.c"
}


static void _app_window_on_undo_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 449 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_undo ((AppWindow*) self);
#line 2323 "AppWindow.c"
}


static void _app_window_on_redo_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 449 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_redo ((AppWindow*) self);
#line 2330 "AppWindow.c"
}


static void _app_window_on_jump_to_file_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 449 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_jump_to_file ((AppWindow*) self);
#line 2337 "AppWindow.c"
}


static void _app_window_on_select_all_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 449 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_select_all ((AppWindow*) self);
#line 2344 "AppWindow.c"
}


static void _app_window_on_select_none_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 449 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_select_none ((AppWindow*) self);
#line 2351 "AppWindow.c"
}


static void _app_window_on_command_manager_altered_command_manager_altered (CommandManager* _sender, gboolean can_undo, gboolean can_redo, gpointer self) {
#line 430 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_command_manager_altered ((AppWindow*) self);
#line 2358 "AppWindow.c"
}


AppWindow* app_window_construct (GType object_type) {
	AppWindow * self = NULL;
	AppWindow* _tmp0_;
	AppWindow* _tmp1_;
	Dimensions _tmp10_;
	gint _tmp11_;
	Dimensions _tmp12_;
	gint _tmp13_;
	gboolean _tmp14_;
	CommandManager* _tmp15_;
	CommandManager* _tmp16_;
	CommandManager* _tmp17_;
	GtkCssProvider* provider = NULL;
	GtkCssProvider* _tmp18_;
	GError * _inner_error_ = NULL;
#line 407 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = (AppWindow*) page_window_construct (object_type);
#line 409 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_instance;
#line 409 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_vala_assert (_tmp0_ == NULL, "instance == null");
#line 410 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _g_object_ref0 (self);
#line 410 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (app_window_instance);
#line 410 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_instance = _tmp1_;
#line 412 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), RESOURCES_APP_TITLE);
#line 413 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_default_icon_name ("shotwell");
#line 416 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, TYPE_LIBRARY_WINDOW)) {
#line 2395 "AppWindow.c"
		ConfigFacade* _tmp2_;
		ConfigFacade* _tmp3_;
		gboolean _tmp4_ = FALSE;
		Dimensions _tmp5_ = {0};
#line 417 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = config_facade_get_instance ();
#line 417 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = _tmp2_;
#line 417 "/home/jens/Source/shotwell/src/AppWindow.vala"
		configuration_facade_get_library_window_state (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), &_tmp4_, &_tmp5_);
#line 417 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->maximized = _tmp4_;
#line 417 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->dimensions = _tmp5_;
#line 417 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp3_);
#line 2412 "AppWindow.c"
	} else {
		ConfigFacade* _tmp6_;
		ConfigFacade* _tmp7_;
		gboolean _tmp8_ = FALSE;
		Dimensions _tmp9_ = {0};
#line 419 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (self, TYPE_DIRECT_WINDOW), "this is DirectWindow");
#line 420 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = config_facade_get_instance ();
#line 420 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = _tmp6_;
#line 420 "/home/jens/Source/shotwell/src/AppWindow.vala"
		configuration_facade_get_direct_window_state (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), &_tmp8_, &_tmp9_);
#line 420 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->maximized = _tmp8_;
#line 420 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->dimensions = _tmp9_;
#line 420 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp7_);
#line 2432 "AppWindow.c"
	}
#line 423 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = self->dimensions;
#line 423 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp11_ = _tmp10_.width;
#line 423 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp12_ = self->dimensions;
#line 423 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp13_ = _tmp12_.height;
#line 423 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_default_size (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp11_, _tmp13_);
#line 425 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp14_ = self->maximized;
#line 425 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp14_) {
#line 426 "/home/jens/Source/shotwell/src/AppWindow.vala"
		gtk_window_maximize (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 2450 "AppWindow.c"
	}
#line 428 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp15_ = app_window_command_manager;
#line 428 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_vala_assert (_tmp15_ == NULL, "command_manager == null");
#line 429 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp16_ = command_manager_new (COMMAND_MANAGER_DEFAULT_DEPTH);
#line 429 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_command_manager_unref0 (app_window_command_manager);
#line 429 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_command_manager = _tmp16_;
#line 430 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp17_ = app_window_command_manager;
#line 430 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_signal_connect_object (_tmp17_, "altered", (GCallback) _app_window_on_command_manager_altered_command_manager_altered, self, 0);
#line 438 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_add_actions (self);
#line 440 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp18_ = gtk_css_provider_new ();
#line 440 "/home/jens/Source/shotwell/src/AppWindow.vala"
	provider = _tmp18_;
#line 2472 "AppWindow.c"
	{
		GdkScreen* _tmp19_;
#line 442 "/home/jens/Source/shotwell/src/AppWindow.vala"
		gtk_css_provider_load_from_data (provider, RESOURCES_CUSTOM_CSS, (gssize) -1, &_inner_error_);
#line 442 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2479 "AppWindow.c"
			goto __catch227_g_error;
		}
#line 443 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp19_ = gdk_screen_get_default ();
#line 443 "/home/jens/Source/shotwell/src/AppWindow.vala"
		gtk_style_context_add_provider_for_screen (_tmp19_, G_TYPE_CHECK_INSTANCE_CAST (provider, GTK_TYPE_STYLE_PROVIDER, GtkStyleProvider), (guint) GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
#line 2486 "AppWindow.c"
	}
	goto __finally227;
	__catch227_g_error:
	{
		GError* err = NULL;
		GError* _tmp20_;
		const gchar* _tmp21_;
#line 441 "/home/jens/Source/shotwell/src/AppWindow.vala"
		err = _inner_error_;
#line 441 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_inner_error_ = NULL;
#line 445 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp20_ = err;
#line 445 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp21_ = _tmp20_->message;
#line 445 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_debug ("AppWindow.vala:445: Unable to load custom CSS: %s", _tmp21_);
#line 441 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_error_free0 (err);
#line 2506 "AppWindow.c"
	}
	__finally227:
#line 441 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 441 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (provider);
#line 441 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 441 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_clear_error (&_inner_error_);
#line 441 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return NULL;
#line 2519 "AppWindow.c"
	}
#line 407 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (provider);
#line 407 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return self;
#line 2525 "AppWindow.c"
}


static void app_window_real_on_fullscreen (AppWindow* self) {
#line 463 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_critical ("Type `%s' does not implement abstract method `app_window_on_fullscreen'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 463 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return;
#line 2534 "AppWindow.c"
}


void app_window_on_fullscreen (AppWindow* self) {
#line 463 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 463 "/home/jens/Source/shotwell/src/AppWindow.vala"
	APP_WINDOW_GET_CLASS (self)->on_fullscreen (self);
#line 2543 "AppWindow.c"
}


gboolean app_window_has_instance (void) {
	gboolean result = FALSE;
	AppWindow* _tmp0_;
#line 466 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_instance;
#line 466 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp0_ != NULL;
#line 466 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2556 "AppWindow.c"
}


AppWindow* app_window_get_instance (void) {
	AppWindow* result = NULL;
	AppWindow* _tmp0_;
	AppWindow* _tmp1_;
#line 470 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_instance;
#line 470 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 470 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp1_;
#line 470 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2572 "AppWindow.c"
}


FullscreenWindow* app_window_get_fullscreen (void) {
	FullscreenWindow* result = NULL;
	FullscreenWindow* _tmp0_;
	FullscreenWindow* _tmp1_;
#line 474 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_fullscreen_window;
#line 474 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 474 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp1_;
#line 474 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2588 "AppWindow.c"
}


GtkBuilder* app_window_create_builder (const gchar* glade_filename, void* user) {
	GtkBuilder* result = NULL;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_;
	void* _tmp6_;
	GError * _inner_error_ = NULL;
#line 477 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (glade_filename != NULL, NULL);
#line 478 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = gtk_builder_new ();
#line 478 "/home/jens/Source/shotwell/src/AppWindow.vala"
	builder = _tmp0_;
#line 2604 "AppWindow.c"
	{
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 480 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = glade_filename;
#line 480 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = resources_get_ui (_tmp1_);
#line 480 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = _tmp2_;
#line 480 "/home/jens/Source/shotwell/src/AppWindow.vala"
		gtk_builder_add_from_resource (builder, _tmp3_, &_inner_error_);
#line 480 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp3_);
#line 480 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2621 "AppWindow.c"
			goto __catch228_g_error;
		}
	}
	goto __finally228;
	__catch228_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp4_;
		const gchar* _tmp5_;
#line 479 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_error_ = _inner_error_;
#line 479 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_inner_error_ = NULL;
#line 482 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = _error_;
#line 482 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp4_->message;
#line 482 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_warning ("AppWindow.vala:482: Unable to create Gtk.Builder: %s\n", _tmp5_);
#line 479 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_error_free0 (_error_);
#line 2643 "AppWindow.c"
	}
	__finally228:
#line 479 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 479 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (builder);
#line 479 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 479 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_clear_error (&_inner_error_);
#line 479 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return NULL;
#line 2656 "AppWindow.c"
	}
#line 485 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = user;
#line 485 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_builder_connect_signals (builder, _tmp6_);
#line 487 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = builder;
#line 487 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2666 "AppWindow.c"
}


void app_window_error_message (const gchar* message, GtkWindow* parent) {
	const gchar* _tmp0_;
	GtkWindow* _tmp1_;
#line 490 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (message != NULL);
#line 490 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((parent == NULL) || GTK_IS_WINDOW (parent));
#line 491 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = message;
#line 491 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = parent;
#line 491 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_error_message_with_title (RESOURCES_APP_TITLE, _tmp0_, _tmp1_, TRUE);
#line 2683 "AppWindow.c"
}


void app_window_error_message_with_title (const gchar* title, const gchar* message, GtkWindow* parent, gboolean should_escape) {
	GtkWindow* _tmp0_ = NULL;
	GtkWindow* _tmp1_;
	GtkMessageDialog* dialog = NULL;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gboolean _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	GtkMessageDialog* _tmp10_;
	GtkMessageDialog* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	gboolean _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
#line 494 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (title != NULL);
#line 494 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (message != NULL);
#line 494 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((parent == NULL) || GTK_IS_WINDOW (parent));
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = parent;
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ != NULL) {
#line 2713 "AppWindow.c"
		GtkWindow* _tmp2_;
		GtkWindow* _tmp3_;
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = parent;
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = _g_object_ref0 (_tmp2_);
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp3_;
#line 2724 "AppWindow.c"
	} else {
		AppWindow* _tmp4_;
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = app_window_get_instance ();
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_window_get_type (), GtkWindow);
#line 2733 "AppWindow.c"
	}
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = title;
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = message;
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = should_escape;
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = build_alert_body_text (_tmp5_, _tmp6_, _tmp7_);
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp9_ = _tmp8_;
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = (GtkMessageDialog*) gtk_message_dialog_new_with_markup (_tmp0_, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", _tmp9_);
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp10_);
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp11_ = _tmp10_;
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp9_);
#line 498 "/home/jens/Source/shotwell/src/AppWindow.vala"
	dialog = _tmp11_;
#line 502 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp12_ = title;
#line 502 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp13_ = message;
#line 502 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp14_ = should_escape;
#line 502 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp15_ = build_alert_body_text (_tmp12_, _tmp13_, _tmp14_);
#line 502 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp16_ = _tmp15_;
#line 502 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_message_dialog_set_markup (dialog, _tmp16_);
#line 502 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp16_);
#line 504 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_set (dialog, "use-markup", TRUE, NULL);
#line 505 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 506 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 494 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (dialog);
#line 494 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp0_);
#line 2779 "AppWindow.c"
}


gboolean app_window_negate_affirm_question (const gchar* message, const gchar* negative, const gchar* affirmative, const gchar* title, GtkWindow* parent) {
	gboolean result = FALSE;
	GtkWindow* _tmp0_ = NULL;
	GtkWindow* _tmp1_;
	GtkMessageDialog* dialog = NULL;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	GtkMessageDialog* _tmp9_;
	GtkMessageDialog* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	gboolean response = FALSE;
	gint _tmp17_;
#line 509 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (message != NULL, FALSE);
#line 509 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (negative != NULL, FALSE);
#line 509 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (affirmative != NULL, FALSE);
#line 509 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail ((parent == NULL) || GTK_IS_WINDOW (parent), FALSE);
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = parent;
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ != NULL) {
#line 2814 "AppWindow.c"
		GtkWindow* _tmp2_;
		GtkWindow* _tmp3_;
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = parent;
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = _g_object_ref0 (_tmp2_);
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp3_;
#line 2825 "AppWindow.c"
	} else {
		AppWindow* _tmp4_;
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = app_window_get_instance ();
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_window_get_type (), GtkWindow);
#line 2834 "AppWindow.c"
	}
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = title;
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = message;
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = build_alert_body_text (_tmp5_, _tmp6_, TRUE);
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = _tmp7_;
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp9_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp0_, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", _tmp8_);
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp9_);
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = _tmp9_;
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp8_);
#line 511 "/home/jens/Source/shotwell/src/AppWindow.vala"
	dialog = _tmp10_;
#line 514 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp11_ = title;
#line 514 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp12_ = message;
#line 514 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp13_ = build_alert_body_text (_tmp11_, _tmp12_, TRUE);
#line 514 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp14_ = _tmp13_;
#line 514 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_message_dialog_set_markup (dialog, _tmp14_);
#line 514 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp14_);
#line 515 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp15_ = negative;
#line 515 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp16_ = affirmative;
#line 515 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _tmp15_, GTK_RESPONSE_NO, _tmp16_, GTK_RESPONSE_YES, NULL);
#line 516 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_urgency_hint (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_window_get_type (), GtkWindow), TRUE);
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp17_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 518 "/home/jens/Source/shotwell/src/AppWindow.vala"
	response = _tmp17_ == ((gint) GTK_RESPONSE_YES);
#line 520 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 522 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = response;
#line 522 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (dialog);
#line 522 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp0_);
#line 522 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2888 "AppWindow.c"
}


GtkResponseType app_window_negate_affirm_cancel_question (const gchar* message, const gchar* negative, const gchar* affirmative, const gchar* title, GtkWindow* parent) {
	GtkResponseType result = 0;
	GtkWindow* _tmp0_ = NULL;
	GtkWindow* _tmp1_;
	GtkMessageDialog* dialog = NULL;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	GtkMessageDialog* _tmp9_;
	GtkMessageDialog* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gint response = 0;
	gint _tmp17_;
#line 525 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (message != NULL, 0);
#line 525 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (negative != NULL, 0);
#line 525 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (affirmative != NULL, 0);
#line 525 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail ((parent == NULL) || GTK_IS_WINDOW (parent), 0);
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = parent;
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ != NULL) {
#line 2923 "AppWindow.c"
		GtkWindow* _tmp2_;
		GtkWindow* _tmp3_;
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = parent;
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = _g_object_ref0 (_tmp2_);
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp3_;
#line 2934 "AppWindow.c"
	} else {
		AppWindow* _tmp4_;
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = app_window_get_instance ();
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_window_get_type (), GtkWindow);
#line 2943 "AppWindow.c"
	}
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = title;
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = message;
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = build_alert_body_text (_tmp5_, _tmp6_, TRUE);
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = _tmp7_;
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp9_ = (GtkMessageDialog*) gtk_message_dialog_new_with_markup (_tmp0_, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", _tmp8_);
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp9_);
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = _tmp9_;
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp8_);
#line 527 "/home/jens/Source/shotwell/src/AppWindow.vala"
	dialog = _tmp10_;
#line 530 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp11_ = negative;
#line 530 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp12_ = affirmative;
#line 530 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _tmp11_, GTK_RESPONSE_NO, _tmp12_, GTK_RESPONSE_YES, _ ("_Cancel"), GTK_RESPONSE_CANCEL, NULL);
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp13_ = title;
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp14_ = message;
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp15_ = build_alert_body_text (_tmp13_, _tmp14_, TRUE);
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp16_ = _tmp15_;
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_message_dialog_set_markup (dialog, _tmp16_);
#line 534 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp16_);
#line 535 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_set (dialog, "use-markup", TRUE, NULL);
#line 537 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp17_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 537 "/home/jens/Source/shotwell/src/AppWindow.vala"
	response = _tmp17_;
#line 539 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 541 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = (GtkResponseType) response;
#line 541 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (dialog);
#line 541 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp0_);
#line 541 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 2997 "AppWindow.c"
}


GtkResponseType app_window_affirm_cancel_question (const gchar* message, const gchar* affirmative, const gchar* title, GtkWindow* parent) {
	GtkResponseType result = 0;
	GtkWindow* _tmp0_ = NULL;
	GtkWindow* _tmp1_;
	GtkMessageDialog* dialog = NULL;
	const gchar* _tmp5_;
	GtkMessageDialog* _tmp6_;
	GtkMessageDialog* _tmp7_;
	const gchar* _tmp8_;
	GtkMessageDialog* _tmp9_;
	const gchar* _tmp10_ = NULL;
	const gchar* _tmp11_;
	GtkMessageDialog* _tmp13_;
	GtkMessageDialog* _tmp14_;
	const gchar* _tmp15_;
	gint response = 0;
	GtkMessageDialog* _tmp16_;
	gint _tmp17_;
	GtkMessageDialog* _tmp18_;
#line 544 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (message != NULL, 0);
#line 544 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (affirmative != NULL, 0);
#line 544 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail ((parent == NULL) || GTK_IS_WINDOW (parent), 0);
#line 546 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = parent;
#line 546 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ != NULL) {
#line 3030 "AppWindow.c"
		GtkWindow* _tmp2_;
		GtkWindow* _tmp3_;
#line 546 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = parent;
#line 546 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = _g_object_ref0 (_tmp2_);
#line 546 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 546 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp3_;
#line 3041 "AppWindow.c"
	} else {
		AppWindow* _tmp4_;
#line 546 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = app_window_get_instance ();
#line 546 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 546 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_window_get_type (), GtkWindow);
#line 3050 "AppWindow.c"
	}
#line 546 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = message;
#line 546 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = (GtkMessageDialog*) gtk_message_dialog_new_with_markup (_tmp0_, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", _tmp5_);
#line 546 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp6_);
#line 546 "/home/jens/Source/shotwell/src/AppWindow.vala"
	dialog = _tmp6_;
#line 549 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = dialog;
#line 549 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = message;
#line 549 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_message_dialog_set_markup (_tmp7_, _tmp8_);
#line 550 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp9_ = dialog;
#line 550 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_set (_tmp9_, "use-markup", TRUE, NULL);
#line 551 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp11_ = title;
#line 551 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp11_ != NULL) {
#line 3074 "AppWindow.c"
		const gchar* _tmp12_;
#line 551 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp12_ = title;
#line 551 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp10_ = _tmp12_;
#line 3080 "AppWindow.c"
	} else {
#line 551 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp10_ = RESOURCES_APP_TITLE;
#line 3084 "AppWindow.c"
	}
#line 551 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp13_ = dialog;
#line 551 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_window_get_type (), GtkWindow), _tmp10_);
#line 552 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp14_ = dialog;
#line 552 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp15_ = affirmative;
#line 552 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_dialog_get_type (), GtkDialog), _tmp15_, GTK_RESPONSE_YES, _ ("_Cancel"), GTK_RESPONSE_CANCEL, NULL);
#line 555 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp16_ = dialog;
#line 555 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp17_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_dialog_get_type (), GtkDialog));
#line 555 "/home/jens/Source/shotwell/src/AppWindow.vala"
	response = _tmp17_;
#line 557 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp18_ = dialog;
#line 557 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_widget_get_type (), GtkWidget));
#line 559 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = (GtkResponseType) response;
#line 559 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (dialog);
#line 559 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp0_);
#line 559 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 3114 "AppWindow.c"
}


GtkResponseType app_window_negate_affirm_all_cancel_question (const gchar* message, const gchar* negative, const gchar* affirmative, const gchar* affirmative_all, const gchar* title, GtkWindow* parent) {
	GtkResponseType result = 0;
	GtkWindow* _tmp0_ = NULL;
	GtkWindow* _tmp1_;
	GtkMessageDialog* dialog = NULL;
	const gchar* _tmp5_;
	GtkMessageDialog* _tmp6_;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_;
	GtkMessageDialog* _tmp10_;
	GtkMessageDialog* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	gint response = 0;
	GtkMessageDialog* _tmp15_;
	gint _tmp16_;
	GtkMessageDialog* _tmp17_;
#line 562 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (message != NULL, 0);
#line 562 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (negative != NULL, 0);
#line 562 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (affirmative != NULL, 0);
#line 562 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (affirmative_all != NULL, 0);
#line 562 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail ((parent == NULL) || GTK_IS_WINDOW (parent), 0);
#line 565 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = parent;
#line 565 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ != NULL) {
#line 3150 "AppWindow.c"
		GtkWindow* _tmp2_;
		GtkWindow* _tmp3_;
#line 565 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = parent;
#line 565 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = _g_object_ref0 (_tmp2_);
#line 565 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 565 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = _tmp3_;
#line 3161 "AppWindow.c"
	} else {
		AppWindow* _tmp4_;
#line 565 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = app_window_get_instance ();
#line 565 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 565 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_window_get_type (), GtkWindow);
#line 3170 "AppWindow.c"
	}
#line 565 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = message;
#line 565 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp0_, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", _tmp5_);
#line 565 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp6_);
#line 565 "/home/jens/Source/shotwell/src/AppWindow.vala"
	dialog = _tmp6_;
#line 567 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = title;
#line 567 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp8_ != NULL) {
#line 3184 "AppWindow.c"
		const gchar* _tmp9_;
#line 567 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp9_ = title;
#line 567 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = _tmp9_;
#line 3190 "AppWindow.c"
	} else {
#line 567 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = RESOURCES_APP_TITLE;
#line 3194 "AppWindow.c"
	}
#line 567 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = dialog;
#line 567 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_window_get_type (), GtkWindow), _tmp7_);
#line 568 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp11_ = dialog;
#line 568 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp12_ = negative;
#line 568 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp13_ = affirmative;
#line 568 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp14_ = affirmative_all;
#line 568 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_dialog_get_type (), GtkDialog), _tmp12_, GTK_RESPONSE_NO, _tmp13_, GTK_RESPONSE_YES, _tmp14_, GTK_RESPONSE_APPLY, _ ("_Cancel"), GTK_RESPONSE_CANCEL, NULL);
#line 571 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp15_ = dialog;
#line 571 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp16_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_dialog_get_type (), GtkDialog));
#line 571 "/home/jens/Source/shotwell/src/AppWindow.vala"
	response = _tmp16_;
#line 573 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp17_ = dialog;
#line 573 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_widget_get_type (), GtkWidget));
#line 575 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = (GtkResponseType) response;
#line 575 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (dialog);
#line 575 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp0_);
#line 575 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 3228 "AppWindow.c"
}


void app_window_database_error (GError* err) {
	GError* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 579 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = err;
#line 579 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_->message;
#line 579 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = g_strdup_printf (_ ("A fatal error occurred when accessing Shotwell’s library. Shotwell can" \
"not continue.\n" \
"\n" \
"%s"), _tmp1_);
#line 579 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _tmp2_;
#line 579 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_panic (_tmp3_);
#line 579 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp3_);
#line 3249 "AppWindow.c"
}


void app_window_panic (const gchar* msg) {
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	Application* _tmp2_;
	Application* _tmp3_;
#line 583 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (msg != NULL);
#line 584 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = msg;
#line 584 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_critical ("AppWindow.vala:584: %s", _tmp0_);
#line 585 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = msg;
#line 585 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_error_message (_tmp1_, NULL);
#line 587 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = application_get_instance ();
#line 587 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _tmp2_;
#line 587 "/home/jens/Source/shotwell/src/AppWindow.vala"
	application_panic (_tmp3_);
#line 587 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_application_unref0 (_tmp3_);
#line 3276 "AppWindow.c"
}


static gchar* app_window_real_get_app_role (AppWindow* self) {
#line 590 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_critical ("Type `%s' does not implement abstract method `app_window_get_app_role'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 590 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return NULL;
#line 3285 "AppWindow.c"
}


gchar* app_window_get_app_role (AppWindow* self) {
#line 590 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (IS_APP_WINDOW (self), NULL);
#line 590 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return APP_WINDOW_GET_CLASS (self)->get_app_role (self);
#line 3294 "AppWindow.c"
}


void app_window_on_about (AppWindow* self) {
#line 593 "/home/jens/Source/shotwell/src/AppWindow.vala"
	static const gchar* artists[] = {"Aachen logo under public domain license https://www.flickr.com/photos/" \
"30784528@N04/10860988196/", NULL};
#line 3301 "AppWindow.c"
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GdkPixbuf* _tmp4_;
	GdkPixbuf* _tmp5_;
#line 592 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 594 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = g_strdup_printf ("%s \u2013 “Aachen”", RESOURCES_APP_VERSION);
#line 594 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 594 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = app_window_get_app_role (self);
#line 594 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _tmp2_;
#line 594 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = resources_get_icon (RESOURCES_ICON_ABOUT_LOGO, -1);
#line 594 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = _tmp4_;
#line 594 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_show_about_dialog (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), "version", _ (_tmp1_), "comments", _tmp3_, "copyright", RESOURCES_COPYRIGHT, "website", RESOURCES_HOME_URL, "license", RESOURCES_LICENSE, "website-label", _ ("Visit the Shotwell web site"), "authors", RESOURCES_AUTHORS, "logo", _tmp5_, "artists", artists, "translator-credits", _ ("translator-credits"), NULL, NULL);
#line 594 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp5_);
#line 594 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp3_);
#line 594 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp1_);
#line 3330 "AppWindow.c"
}


static void app_window_on_help_contents (AppWindow* self) {
	GError * _inner_error_ = NULL;
#line 610 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 3338 "AppWindow.c"
	{
		GdkScreen* _tmp0_;
#line 612 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = gtk_window_get_screen (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 612 "/home/jens/Source/shotwell/src/AppWindow.vala"
		resources_launch_help (_tmp0_, NULL, &_inner_error_);
#line 612 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3347 "AppWindow.c"
			goto __catch229_g_error;
		}
	}
	goto __finally229;
	__catch229_g_error:
	{
		GError* err = NULL;
		GError* _tmp1_;
		const gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
#line 611 "/home/jens/Source/shotwell/src/AppWindow.vala"
		err = _inner_error_;
#line 611 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_inner_error_ = NULL;
#line 614 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = err;
#line 614 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = _tmp1_->message;
#line 614 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = g_strdup_printf (_ ("Unable to display help: %s"), _tmp2_);
#line 614 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = _tmp3_;
#line 614 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_error_message (_tmp4_, NULL);
#line 614 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp4_);
#line 611 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_error_free0 (err);
#line 3377 "AppWindow.c"
	}
	__finally229:
#line 611 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 611 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 611 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_clear_error (&_inner_error_);
#line 611 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 3388 "AppWindow.c"
	}
}


static void app_window_on_help_report_problem (AppWindow* self) {
	GError * _inner_error_ = NULL;
#line 618 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 3397 "AppWindow.c"
	{
#line 620 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_show_uri (self, RESOURCES_BUG_DB_URL, &_inner_error_);
#line 620 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3403 "AppWindow.c"
			goto __catch230_g_error;
		}
	}
	goto __finally230;
	__catch230_g_error:
	{
		GError* err = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 619 "/home/jens/Source/shotwell/src/AppWindow.vala"
		err = _inner_error_;
#line 619 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_inner_error_ = NULL;
#line 622 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = err;
#line 622 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = _tmp0_->message;
#line 622 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = g_strdup_printf (_ ("Unable to navigate to bug database: %s"), _tmp1_);
#line 622 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = _tmp2_;
#line 622 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_error_message (_tmp3_, NULL);
#line 622 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp3_);
#line 619 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_error_free0 (err);
#line 3433 "AppWindow.c"
	}
	__finally230:
#line 619 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 619 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 619 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_clear_error (&_inner_error_);
#line 619 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 3444 "AppWindow.c"
	}
}


static void app_window_on_help_faq (AppWindow* self) {
	GError * _inner_error_ = NULL;
#line 626 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 3453 "AppWindow.c"
	{
#line 628 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_show_uri (self, RESOURCES_FAQ_URL, &_inner_error_);
#line 628 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3459 "AppWindow.c"
			goto __catch231_g_error;
		}
	}
	goto __finally231;
	__catch231_g_error:
	{
		GError* err = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 627 "/home/jens/Source/shotwell/src/AppWindow.vala"
		err = _inner_error_;
#line 627 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_inner_error_ = NULL;
#line 630 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp0_ = err;
#line 630 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = _tmp0_->message;
#line 630 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = g_strdup_printf (_ ("Unable to display FAQ: %s"), _tmp1_);
#line 630 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = _tmp2_;
#line 630 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_error_message (_tmp3_, NULL);
#line 630 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp3_);
#line 627 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_error_free0 (err);
#line 3489 "AppWindow.c"
	}
	__finally231:
#line 627 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 627 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 627 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_clear_error (&_inner_error_);
#line 627 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 3500 "AppWindow.c"
	}
}


static void app_window_real_on_quit (AppWindow* self) {
	Application* _tmp0_;
	Application* _tmp1_;
#line 635 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = application_get_instance ();
#line 635 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 635 "/home/jens/Source/shotwell/src/AppWindow.vala"
	application_exit (_tmp1_);
#line 635 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_application_unref0 (_tmp1_);
#line 3516 "AppWindow.c"
}


void app_window_on_quit (AppWindow* self) {
#line 634 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 634 "/home/jens/Source/shotwell/src/AppWindow.vala"
	APP_WINDOW_GET_CLASS (self)->on_quit (self);
#line 3525 "AppWindow.c"
}


void app_window_on_jump_to_file (AppWindow* self) {
	Page* _tmp0_;
	Page* _tmp1_;
	ViewCollection* _tmp2_;
	ViewCollection* _tmp3_;
	gint _tmp4_;
	gboolean _tmp5_;
	MediaSource* media = NULL;
	Page* _tmp6_;
	Page* _tmp7_;
	ViewCollection* _tmp8_;
	ViewCollection* _tmp9_;
	DataView* _tmp10_;
	DataView* _tmp11_;
	DataSource* _tmp12_;
	MediaSource* _tmp13_;
	MediaSource* _tmp14_;
	MediaSource* _tmp15_;
	GError * _inner_error_ = NULL;
#line 638 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 639 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 639 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 639 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = page_get_view (_tmp1_);
#line 639 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _tmp2_;
#line 639 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = view_collection_get_selected_count (_tmp3_);
#line 639 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = _tmp4_ != 1;
#line 639 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_data_collection_unref0 (_tmp3_);
#line 639 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 639 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp5_) {
#line 640 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 3570 "AppWindow.c"
	}
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = _tmp6_;
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = page_get_view (_tmp7_);
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp9_ = _tmp8_;
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = view_collection_get_selected_at (_tmp9_, 0);
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp11_ = _tmp10_;
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp12_ = data_view_get_source (_tmp11_);
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, TYPE_MEDIA_SOURCE) ? ((MediaSource*) _tmp12_) : NULL;
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp13_ == NULL) {
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp12_);
#line 3592 "AppWindow.c"
	}
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp14_ = _tmp13_;
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp11_);
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_data_collection_unref0 (_tmp9_);
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp7_);
#line 642 "/home/jens/Source/shotwell/src/AppWindow.vala"
	media = _tmp14_;
#line 644 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp15_ = media;
#line 644 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp15_ == NULL) {
#line 645 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (media);
#line 645 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 3612 "AppWindow.c"
	}
	{
		AppWindow* _tmp16_;
		AppWindow* _tmp17_;
		MediaSource* _tmp18_;
		GFile* _tmp19_;
		GFile* _tmp20_;
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp16_ = app_window_get_instance ();
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp17_ = _tmp16_;
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp18_ = media;
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp19_ = media_source_get_master_file (_tmp18_);
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp20_ = _tmp19_;
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_show_file_uri (_tmp17_, _tmp20_, &_inner_error_);
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp20_);
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp17_);
#line 648 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3638 "AppWindow.c"
			goto __catch232_g_error;
		}
	}
	goto __finally232;
	__catch232_g_error:
	{
		GError* err = NULL;
		GError* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
#line 647 "/home/jens/Source/shotwell/src/AppWindow.vala"
		err = _inner_error_;
#line 647 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_inner_error_ = NULL;
#line 650 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp21_ = err;
#line 650 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp22_ = resources_jump_to_file_failed (_tmp21_);
#line 650 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp23_ = _tmp22_;
#line 650 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_error_message (_tmp23_, NULL);
#line 650 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp23_);
#line 647 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_error_free0 (err);
#line 3665 "AppWindow.c"
	}
	__finally232:
#line 647 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 647 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (media);
#line 647 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 647 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_clear_error (&_inner_error_);
#line 647 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 3678 "AppWindow.c"
	}
#line 638 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (media);
#line 3682 "AppWindow.c"
}


static void app_window_real_destroy (GtkWidget* base) {
	AppWindow * self;
#line 654 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_APP_WINDOW, AppWindow);
#line 655 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_quit (self);
#line 3692 "AppWindow.c"
}


static gchar* string_replace (const gchar* self, const gchar* old, const gchar* replacement) {
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GError * _inner_error_ = NULL;
#line 1407 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1407 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (old != NULL, NULL);
#line 1407 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (replacement != NULL, NULL);
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if ((*((gchar*) self)) == '\0') {
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 3711 "AppWindow.c"
	} else {
		const gchar* _tmp2_;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp2_ = old;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp1_ = (*((gchar*) _tmp2_)) == '\0';
#line 3718 "AppWindow.c"
	}
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp0_ = TRUE;
#line 3724 "AppWindow.c"
	} else {
		const gchar* _tmp3_;
		const gchar* _tmp4_;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp3_ = old;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4_ = replacement;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp0_ = g_strcmp0 (_tmp3_, _tmp4_) == 0;
#line 3734 "AppWindow.c"
	}
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 3738 "AppWindow.c"
		gchar* _tmp5_;
#line 1409 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp5_ = g_strdup (self);
#line 1409 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = _tmp5_;
#line 1409 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 3746 "AppWindow.c"
	}
	{
		GRegex* regex = NULL;
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		GRegex* _tmp9_;
		GRegex* _tmp10_;
		gchar* _tmp11_ = NULL;
		GRegex* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6_ = old;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp7_ = g_regex_escape_string (_tmp6_, -1);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp8_ = _tmp7_;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp9_ = g_regex_new (_tmp8_, 0, 0, &_inner_error_);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp10_ = _tmp9_;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_g_free0 (_tmp8_);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		regex = _tmp10_;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 3778 "AppWindow.c"
				goto __catch233_g_regex_error;
			}
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			return NULL;
#line 3787 "AppWindow.c"
		}
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp12_ = regex;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp13_ = replacement;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp14_ = g_regex_replace_literal (_tmp12_, self, (gssize) -1, 0, _tmp13_, 0, &_inner_error_);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp11_ = _tmp14_;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 3803 "AppWindow.c"
				goto __catch233_g_regex_error;
			}
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			return NULL;
#line 3814 "AppWindow.c"
		}
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp15_ = _tmp11_;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp11_ = NULL;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = _tmp15_;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_g_free0 (_tmp11_);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_g_regex_unref0 (regex);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 3828 "AppWindow.c"
	}
	goto __finally233;
	__catch233_g_regex_error:
	{
		GError* e = NULL;
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		e = _inner_error_;
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_inner_error_ = NULL;
#line 1415 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_assert_not_reached ();
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_g_error_free0 (e);
#line 3842 "AppWindow.c"
	}
	__finally233:
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_clear_error (&_inner_error_);
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return NULL;
#line 3853 "AppWindow.c"
	}
}


void app_window_show_file_uri (AppWindow* self, GFile* file, GError** error) {
	gchar* tmp = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gboolean _tmp2_;
	GError * _inner_error_ = NULL;
#line 658 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 658 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (G_IS_FILE (file));
#line 663 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = get_nautilus_install_location ();
#line 663 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 663 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = _tmp1_ != NULL;
#line 663 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (_tmp1_);
#line 663 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_) {
#line 3878 "AppWindow.c"
		GFile* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		const gchar* _tmp7_;
#line 664 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = file;
#line 664 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = g_file_get_uri (_tmp3_);
#line 664 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp4_;
#line 664 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = string_replace (_tmp5_, "'", "\\\'");
#line 664 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (tmp);
#line 664 "/home/jens/Source/shotwell/src/AppWindow.vala"
		tmp = _tmp6_;
#line 664 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp5_);
#line 665 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = tmp;
#line 665 "/home/jens/Source/shotwell/src/AppWindow.vala"
		show_file_in_nautilus (_tmp7_, &_inner_error_);
#line 665 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 665 "/home/jens/Source/shotwell/src/AppWindow.vala"
			g_propagate_error (error, _inner_error_);
#line 665 "/home/jens/Source/shotwell/src/AppWindow.vala"
			_g_free0 (tmp);
#line 665 "/home/jens/Source/shotwell/src/AppWindow.vala"
			return;
#line 3910 "AppWindow.c"
		}
	} else {
		GFile* _tmp8_;
		GFile* _tmp9_;
		GFile* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		const gchar* _tmp14_;
#line 667 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp8_ = file;
#line 667 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp9_ = g_file_get_parent (_tmp8_);
#line 667 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp10_ = _tmp9_;
#line 667 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp11_ = g_file_get_uri (_tmp10_);
#line 667 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp12_ = _tmp11_;
#line 667 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp13_ = string_replace (_tmp12_, "'", "\\\'");
#line 667 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (tmp);
#line 667 "/home/jens/Source/shotwell/src/AppWindow.vala"
		tmp = _tmp13_;
#line 667 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp12_);
#line 667 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp10_);
#line 668 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp14_ = tmp;
#line 668 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_show_uri (self, _tmp14_, &_inner_error_);
#line 668 "/home/jens/Source/shotwell/src/AppWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 668 "/home/jens/Source/shotwell/src/AppWindow.vala"
			g_propagate_error (error, _inner_error_);
#line 668 "/home/jens/Source/shotwell/src/AppWindow.vala"
			_g_free0 (tmp);
#line 668 "/home/jens/Source/shotwell/src/AppWindow.vala"
			return;
#line 3952 "AppWindow.c"
		}
	}
#line 658 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (tmp);
#line 3957 "AppWindow.c"
}


void app_window_show_uri (AppWindow* self, const gchar* url, GError** error) {
	GdkWindow* _tmp0_;
	GdkScreen* _tmp1_;
	const gchar* _tmp2_;
	GError * _inner_error_ = NULL;
#line 672 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 672 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (url != NULL);
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gdk_window_get_screen (_tmp0_);
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = url;
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
	sys_show_uri (_tmp1_, _tmp2_, &_inner_error_);
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_propagate_error (error, _inner_error_);
#line 673 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 3984 "AppWindow.c"
	}
}


static void app_window_real_add_actions (AppWindow* self) {
#line 677 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_action_map_add_action_entries (G_TYPE_CHECK_INSTANCE_CAST (self, g_action_map_get_type (), GActionMap), APP_WINDOW_common_actions, G_N_ELEMENTS (APP_WINDOW_common_actions), self);
#line 3992 "AppWindow.c"
}


void app_window_add_actions (AppWindow* self) {
#line 676 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 676 "/home/jens/Source/shotwell/src/AppWindow.vala"
	APP_WINDOW_GET_CLASS (self)->add_actions (self);
#line 4001 "AppWindow.c"
}


void app_window_go_fullscreen (AppWindow* self, Page* page) {
	FullscreenWindow* _tmp0_;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	FullscreenWindow* fsw = NULL;
	Page* _tmp4_;
	FullscreenWindow* _tmp5_;
	Page* _tmp6_;
	Page* _tmp7_;
	gboolean _tmp8_;
	FullscreenWindow* _tmp12_;
	FullscreenWindow* _tmp13_;
	FullscreenWindow* _tmp14_;
#line 680 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 680 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 682 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_fullscreen_window;
#line 682 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_ != NULL) {
#line 4026 "AppWindow.c"
		FullscreenWindow* _tmp1_;
#line 683 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = app_window_fullscreen_window;
#line 683 "/home/jens/Source/shotwell/src/AppWindow.vala"
		gtk_window_present (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_window_get_type (), GtkWindow));
#line 685 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 4034 "AppWindow.c"
	}
#line 688 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_get_position (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), &_tmp2_, &_tmp3_);
#line 688 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->pos_x = _tmp2_;
#line 688 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->pos_y = _tmp3_;
#line 689 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 691 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = page;
#line 691 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = fullscreen_window_new (_tmp4_);
#line 691 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_object_ref_sink (_tmp5_);
#line 691 "/home/jens/Source/shotwell/src/AppWindow.vala"
	fsw = _tmp5_;
#line 693 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 693 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = _tmp6_;
#line 693 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp8_ = _tmp7_ != NULL;
#line 693 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp7_);
#line 693 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp8_) {
#line 4062 "AppWindow.c"
		Page* _tmp9_;
		Page* _tmp10_;
		FullscreenWindow* _tmp11_;
#line 694 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp9_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 694 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp10_ = _tmp9_;
#line 694 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp11_ = fsw;
#line 694 "/home/jens/Source/shotwell/src/AppWindow.vala"
		page_switching_to_fullscreen (_tmp10_, _tmp11_);
#line 694 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp10_);
#line 4076 "AppWindow.c"
	}
#line 696 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp12_ = fsw;
#line 696 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp13_ = _g_object_ref0 (_tmp12_);
#line 696 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (app_window_fullscreen_window);
#line 696 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_fullscreen_window = _tmp13_;
#line 697 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp14_ = app_window_fullscreen_window;
#line 697 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_present (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_window_get_type (), GtkWindow));
#line 680 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (fsw);
#line 4092 "AppWindow.c"
}


void app_window_end_fullscreen (AppWindow* self) {
	FullscreenWindow* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	Page* _tmp3_;
	Page* _tmp4_;
	gboolean _tmp5_;
	FullscreenWindow* _tmp9_;
	FullscreenWindow* _tmp10_;
#line 700 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 701 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_fullscreen_window;
#line 701 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp0_ == NULL) {
#line 702 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 4113 "AppWindow.c"
	}
#line 704 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = self->pos_x;
#line 704 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = self->pos_y;
#line 704 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_move (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp1_, _tmp2_);
#line 706 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 708 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 708 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = _tmp3_;
#line 708 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = _tmp4_ != NULL;
#line 708 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp4_);
#line 708 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp5_) {
#line 4133 "AppWindow.c"
		Page* _tmp6_;
		Page* _tmp7_;
		FullscreenWindow* _tmp8_;
#line 709 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 709 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = _tmp6_;
#line 709 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp8_ = app_window_fullscreen_window;
#line 709 "/home/jens/Source/shotwell/src/AppWindow.vala"
		page_returning_from_fullscreen (_tmp7_, _tmp8_);
#line 709 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp7_);
#line 4147 "AppWindow.c"
	}
#line 711 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp9_ = app_window_fullscreen_window;
#line 711 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget));
#line 712 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp10_ = app_window_fullscreen_window;
#line 712 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget));
#line 713 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (app_window_fullscreen_window);
#line 713 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_fullscreen_window = NULL;
#line 715 "/home/jens/Source/shotwell/src/AppWindow.vala"
	gtk_window_present (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 4163 "AppWindow.c"
}


GAction* app_window_get_common_action (AppWindow* self, const gchar* name) {
	GAction* result = NULL;
	const gchar* _tmp0_;
	GAction* _tmp1_;
	GAction* _tmp2_;
#line 718 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (IS_APP_WINDOW (self), NULL);
#line 718 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 719 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = name;
#line 719 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = g_action_map_lookup_action (G_TYPE_CHECK_INSTANCE_CAST (self, g_action_map_get_type (), GActionMap), _tmp0_);
#line 719 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 719 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp2_;
#line 719 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 4186 "AppWindow.c"
}


void app_window_set_common_action_sensitive (AppWindow* self, const gchar* name, gboolean sensitive) {
	GSimpleAction* action = NULL;
	const gchar* _tmp0_;
	GAction* _tmp1_;
	GSimpleAction* _tmp2_;
	GSimpleAction* _tmp3_;
#line 722 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 722 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (name != NULL);
#line 723 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = name;
#line 723 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = app_window_get_common_action (self, _tmp0_);
#line 723 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp1_) : NULL;
#line 723 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_ == NULL) {
#line 723 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp1_);
#line 4210 "AppWindow.c"
	}
#line 723 "/home/jens/Source/shotwell/src/AppWindow.vala"
	action = _tmp2_;
#line 724 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = action;
#line 724 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp3_ != NULL) {
#line 4218 "AppWindow.c"
		GSimpleAction* _tmp4_;
		gboolean _tmp5_;
#line 725 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = action;
#line 725 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = sensitive;
#line 725 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_simple_action_set_enabled (_tmp4_, _tmp5_);
#line 4227 "AppWindow.c"
	}
#line 722 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (action);
#line 4231 "AppWindow.c"
}


void app_window_set_common_action_important (AppWindow* self, const gchar* name, gboolean important) {
	GSimpleAction* action = NULL;
	const gchar* _tmp0_;
	GAction* _tmp1_;
	GSimpleAction* _tmp2_;
	GSimpleAction* _tmp3_;
#line 728 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 728 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (name != NULL);
#line 729 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = name;
#line 729 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = app_window_get_common_action (self, _tmp0_);
#line 729 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp1_) : NULL;
#line 729 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_ == NULL) {
#line 729 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp1_);
#line 4255 "AppWindow.c"
	}
#line 729 "/home/jens/Source/shotwell/src/AppWindow.vala"
	action = _tmp2_;
#line 730 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = action;
#line 730 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp3_ != NULL) {
#line 4263 "AppWindow.c"
		GSimpleAction* _tmp4_;
		gboolean _tmp5_;
		gboolean _tmp6_;
#line 731 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = action;
#line 731 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 731 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = _tmp5_;
#line 731 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_simple_action_set_enabled (_tmp4_, _tmp6_);
#line 4275 "AppWindow.c"
	}
#line 728 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (action);
#line 4279 "AppWindow.c"
}


void app_window_set_common_action_visible (AppWindow* self, const gchar* name, gboolean visible) {
	GSimpleAction* action = NULL;
	const gchar* _tmp0_;
	GAction* _tmp1_;
	GSimpleAction* _tmp2_;
	GSimpleAction* _tmp3_;
#line 734 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 734 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (name != NULL);
#line 735 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = name;
#line 735 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = app_window_get_common_action (self, _tmp0_);
#line 735 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp1_) : NULL;
#line 735 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_ == NULL) {
#line 735 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp1_);
#line 4303 "AppWindow.c"
	}
#line 735 "/home/jens/Source/shotwell/src/AppWindow.vala"
	action = _tmp2_;
#line 736 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = action;
#line 736 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp3_ != NULL) {
#line 4311 "AppWindow.c"
		GSimpleAction* _tmp4_;
		gboolean _tmp5_;
		gboolean _tmp6_;
#line 737 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = action;
#line 737 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 737 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = _tmp5_;
#line 737 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_simple_action_set_enabled (_tmp4_, _tmp6_);
#line 4323 "AppWindow.c"
	}
#line 734 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (action);
#line 4327 "AppWindow.c"
}


static void _app_window_on_update_common_actions_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self) {
#line 744 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_update_common_actions ((AppWindow*) self);
#line 4334 "AppWindow.c"
}


static void _app_window_on_update_common_actions_view_collection_selection_group_altered (ViewCollection* _sender, gpointer self) {
#line 745 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_update_common_actions ((AppWindow*) self);
#line 4341 "AppWindow.c"
}


static void _app_window_on_update_common_actions_view_collection_items_state_changed (ViewCollection* _sender, GeeIterable* changed, gpointer self) {
#line 746 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_on_update_common_actions ((AppWindow*) self);
#line 4348 "AppWindow.c"
}


static void app_window_real_switched_pages (PageWindow* base, Page* old_page, Page* new_page) {
	AppWindow * self;
	Page* _tmp0_;
	Page* _tmp1_;
	Page* _tmp2_;
	Page* _tmp15_;
	Page* _tmp34_;
	Page* _tmp35_;
#line 740 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_APP_WINDOW, AppWindow);
#line 740 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((old_page == NULL) || IS_PAGE (old_page));
#line 740 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((new_page == NULL) || IS_PAGE (new_page));
#line 741 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = old_page;
#line 741 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = new_page;
#line 741 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_update_common_action_availability (self, _tmp0_, _tmp1_);
#line 743 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = old_page;
#line 743 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_ != NULL) {
#line 4376 "AppWindow.c"
		Page* _tmp3_;
		ViewCollection* _tmp4_;
		ViewCollection* _tmp5_;
		guint _tmp6_;
		Page* _tmp7_;
		ViewCollection* _tmp8_;
		ViewCollection* _tmp9_;
		guint _tmp10_;
		Page* _tmp11_;
		ViewCollection* _tmp12_;
		ViewCollection* _tmp13_;
		guint _tmp14_;
#line 744 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = old_page;
#line 744 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = page_get_view (_tmp3_);
#line 744 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp4_;
#line 744 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_parse_name ("contents-altered", TYPE_DATA_COLLECTION, &_tmp6_, NULL, FALSE);
#line 744 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_DATA_COLLECTION, DataCollection), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp6_, 0, NULL, (GCallback) _app_window_on_update_common_actions_data_collection_contents_altered, self);
#line 744 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp5_);
#line 745 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = old_page;
#line 745 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp8_ = page_get_view (_tmp7_);
#line 745 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp9_ = _tmp8_;
#line 745 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_parse_name ("selection-group-altered", TYPE_VIEW_COLLECTION, &_tmp10_, NULL, FALSE);
#line 745 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_handlers_disconnect_matched (_tmp9_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp10_, 0, NULL, (GCallback) _app_window_on_update_common_actions_view_collection_selection_group_altered, self);
#line 745 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp9_);
#line 746 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp11_ = old_page;
#line 746 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp12_ = page_get_view (_tmp11_);
#line 746 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp13_ = _tmp12_;
#line 746 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_parse_name ("items-state-changed", TYPE_VIEW_COLLECTION, &_tmp14_, NULL, FALSE);
#line 746 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_handlers_disconnect_matched (_tmp13_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp14_, 0, NULL, (GCallback) _app_window_on_update_common_actions_view_collection_items_state_changed, self);
#line 746 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp13_);
#line 4425 "AppWindow.c"
	}
#line 749 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp15_ = new_page;
#line 749 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp15_ != NULL) {
#line 4431 "AppWindow.c"
		Page* _tmp16_;
		ViewCollection* _tmp17_;
		ViewCollection* _tmp18_;
		Page* _tmp19_;
		ViewCollection* _tmp20_;
		ViewCollection* _tmp21_;
		Page* _tmp22_;
		ViewCollection* _tmp23_;
		ViewCollection* _tmp24_;
		Page* _tmp25_;
		Page* _tmp26_;
		ViewCollection* _tmp27_;
		ViewCollection* _tmp28_;
		gint _tmp29_;
		Page* _tmp30_;
		ViewCollection* _tmp31_;
		ViewCollection* _tmp32_;
		gint _tmp33_;
#line 750 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp16_ = new_page;
#line 750 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp17_ = page_get_view (_tmp16_);
#line 750 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp18_ = _tmp17_;
#line 750 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, TYPE_DATA_COLLECTION, DataCollection), "contents-altered", (GCallback) _app_window_on_update_common_actions_data_collection_contents_altered, self, 0);
#line 750 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp18_);
#line 751 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp19_ = new_page;
#line 751 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp20_ = page_get_view (_tmp19_);
#line 751 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp21_ = _tmp20_;
#line 751 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_connect_object (_tmp21_, "selection-group-altered", (GCallback) _app_window_on_update_common_actions_view_collection_selection_group_altered, self, 0);
#line 751 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp21_);
#line 752 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp22_ = new_page;
#line 752 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp23_ = page_get_view (_tmp22_);
#line 752 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp24_ = _tmp23_;
#line 752 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_signal_connect_object (_tmp24_, "items-state-changed", (GCallback) _app_window_on_update_common_actions_view_collection_items_state_changed, self, 0);
#line 752 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp24_);
#line 754 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp25_ = new_page;
#line 754 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp26_ = new_page;
#line 754 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp27_ = page_get_view (_tmp26_);
#line 754 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp28_ = _tmp27_;
#line 754 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp29_ = view_collection_get_selected_count (_tmp28_);
#line 754 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp30_ = new_page;
#line 754 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp31_ = page_get_view (_tmp30_);
#line 754 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp32_ = _tmp31_;
#line 754 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp33_ = data_collection_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, TYPE_DATA_COLLECTION, DataCollection));
#line 754 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_update_common_actions (self, _tmp25_, _tmp29_, _tmp33_);
#line 754 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp32_);
#line 754 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp28_);
#line 4504 "AppWindow.c"
	}
#line 758 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp34_ = old_page;
#line 758 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp35_ = new_page;
#line 758 "/home/jens/Source/shotwell/src/AppWindow.vala"
	PAGE_WINDOW_CLASS (app_window_parent_class)->switched_pages (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow), _tmp34_, _tmp35_);
#line 4512 "AppWindow.c"
}


static void app_window_real_update_common_action_availability (AppWindow* self, Page* old_page, Page* new_page) {
	gboolean is_checkerboard = FALSE;
	Page* _tmp0_;
#line 764 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((old_page == NULL) || IS_PAGE (old_page));
#line 764 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((new_page == NULL) || IS_PAGE (new_page));
#line 765 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = new_page;
#line 765 "/home/jens/Source/shotwell/src/AppWindow.vala"
	is_checkerboard = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_CHECKERBOARD_PAGE);
#line 767 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_set_common_action_sensitive (self, "CommonSelectAll", is_checkerboard);
#line 768 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_set_common_action_sensitive (self, "CommonSelectNone", is_checkerboard);
#line 4531 "AppWindow.c"
}


void app_window_update_common_action_availability (AppWindow* self, Page* old_page, Page* new_page) {
#line 764 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 764 "/home/jens/Source/shotwell/src/AppWindow.vala"
	APP_WINDOW_GET_CLASS (self)->update_common_action_availability (self, old_page, new_page);
#line 4540 "AppWindow.c"
}


static void app_window_real_update_common_actions (AppWindow* self, Page* page, gint selected_count, gint count) {
	Page* _tmp0_;
	gint _tmp2_;
#line 774 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 775 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = page;
#line 775 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_CHECKERBOARD_PAGE)) {
#line 4553 "AppWindow.c"
		gint _tmp1_;
#line 776 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp1_ = count;
#line 776 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_set_common_action_sensitive (self, "CommonSelectAll", _tmp1_ > 0);
#line 4559 "AppWindow.c"
	}
#line 777 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = selected_count;
#line 777 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_set_common_action_sensitive (self, "CommonJumpToFile", _tmp2_ == 1);
#line 779 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_decorate_undo_action (self);
#line 780 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_decorate_redo_action (self);
#line 4569 "AppWindow.c"
}


void app_window_update_common_actions (AppWindow* self, Page* page, gint selected_count, gint count) {
#line 774 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 774 "/home/jens/Source/shotwell/src/AppWindow.vala"
	APP_WINDOW_GET_CLASS (self)->update_common_actions (self, page, selected_count, count);
#line 4578 "AppWindow.c"
}


static void app_window_on_update_common_actions (AppWindow* self) {
	Page* page = NULL;
	Page* _tmp0_;
	Page* _tmp1_;
#line 783 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 784 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 784 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page = _tmp0_;
#line 785 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = page;
#line 785 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ != NULL) {
#line 4596 "AppWindow.c"
		Page* _tmp2_;
		Page* _tmp3_;
		ViewCollection* _tmp4_;
		ViewCollection* _tmp5_;
		gint _tmp6_;
		Page* _tmp7_;
		ViewCollection* _tmp8_;
		ViewCollection* _tmp9_;
		gint _tmp10_;
#line 786 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp2_ = page;
#line 786 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = page;
#line 786 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = page_get_view (_tmp3_);
#line 786 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp4_;
#line 786 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp6_ = view_collection_get_selected_count (_tmp5_);
#line 786 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = page;
#line 786 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp8_ = page_get_view (_tmp7_);
#line 786 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp9_ = _tmp8_;
#line 786 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp10_ = data_collection_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_DATA_COLLECTION, DataCollection));
#line 786 "/home/jens/Source/shotwell/src/AppWindow.vala"
		app_window_update_common_actions (self, _tmp2_, _tmp6_, _tmp10_);
#line 786 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp9_);
#line 786 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp5_);
#line 4630 "AppWindow.c"
	}
#line 783 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (page);
#line 4634 "AppWindow.c"
}


void app_window_update_menu_item_label (AppWindow* self, const gchar* id, const gchar* new_label) {
	GMenu* bar = NULL;
	Page* _tmp0_;
	Page* _tmp1_;
	GMenuModel* _tmp2_;
	GMenu* _tmp3_;
	GMenu* _tmp4_;
	GMenu* _tmp5_;
	gint items = 0;
	GMenu* _tmp6_;
	gint _tmp7_;
#line 789 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 789 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (id != NULL);
#line 789 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (new_label != NULL);
#line 791 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 791 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 791 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = page_get_menubar (_tmp1_);
#line 791 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, g_menu_get_type ()) ? ((GMenu*) _tmp2_) : NULL;
#line 791 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp3_ == NULL) {
#line 791 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp2_);
#line 4667 "AppWindow.c"
	}
#line 791 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = _tmp3_;
#line 791 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 791 "/home/jens/Source/shotwell/src/AppWindow.vala"
	bar = _tmp4_;
#line 793 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = bar;
#line 793 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp5_ == NULL) {
#line 794 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (bar);
#line 794 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 4683 "AppWindow.c"
	}
#line 797 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = bar;
#line 797 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp7_ = g_menu_model_get_n_items (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, g_menu_model_get_type (), GMenuModel));
#line 797 "/home/jens/Source/shotwell/src/AppWindow.vala"
	items = _tmp7_;
#line 4691 "AppWindow.c"
	{
		gint i = 0;
#line 798 "/home/jens/Source/shotwell/src/AppWindow.vala"
		i = 0;
#line 4696 "AppWindow.c"
		{
			gboolean _tmp8_ = FALSE;
#line 798 "/home/jens/Source/shotwell/src/AppWindow.vala"
			_tmp8_ = TRUE;
#line 798 "/home/jens/Source/shotwell/src/AppWindow.vala"
			while (TRUE) {
#line 4703 "AppWindow.c"
				gint _tmp10_;
				gint _tmp11_;
				GMenuModel* model = NULL;
				GMenu* _tmp12_;
				gint _tmp13_;
				GMenuModel* _tmp14_;
				GMenu* _tmp15_;
				gint model_items = 0;
				GMenuModel* _tmp16_;
				gint _tmp17_;
#line 798 "/home/jens/Source/shotwell/src/AppWindow.vala"
				if (!_tmp8_) {
#line 4716 "AppWindow.c"
					gint _tmp9_;
#line 798 "/home/jens/Source/shotwell/src/AppWindow.vala"
					_tmp9_ = i;
#line 798 "/home/jens/Source/shotwell/src/AppWindow.vala"
					i = _tmp9_ + 1;
#line 4722 "AppWindow.c"
				}
#line 798 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp8_ = FALSE;
#line 798 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp10_ = i;
#line 798 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp11_ = items;
#line 798 "/home/jens/Source/shotwell/src/AppWindow.vala"
				if (!(_tmp10_ < _tmp11_)) {
#line 798 "/home/jens/Source/shotwell/src/AppWindow.vala"
					break;
#line 4734 "AppWindow.c"
				}
#line 799 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp12_ = bar;
#line 799 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp13_ = i;
#line 799 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp14_ = g_menu_model_get_item_link (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, g_menu_model_get_type (), GMenuModel), _tmp13_, G_MENU_LINK_SUBMENU);
#line 799 "/home/jens/Source/shotwell/src/AppWindow.vala"
				model = _tmp14_;
#line 800 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp15_ = bar;
#line 800 "/home/jens/Source/shotwell/src/AppWindow.vala"
				if (_tmp15_ == NULL) {
#line 801 "/home/jens/Source/shotwell/src/AppWindow.vala"
					_g_object_unref0 (model);
#line 801 "/home/jens/Source/shotwell/src/AppWindow.vala"
					continue;
#line 4752 "AppWindow.c"
				}
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp16_ = model;
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_tmp17_ = g_menu_model_get_n_items (_tmp16_);
#line 804 "/home/jens/Source/shotwell/src/AppWindow.vala"
				model_items = _tmp17_;
#line 4760 "AppWindow.c"
				{
					gint j = 0;
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
					j = 0;
#line 4765 "AppWindow.c"
					{
						gboolean _tmp18_ = FALSE;
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
						_tmp18_ = TRUE;
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
						while (TRUE) {
#line 4772 "AppWindow.c"
							gint _tmp20_;
							gint _tmp21_;
							GMenuModel* subsection = NULL;
							GMenuModel* _tmp22_;
							gint _tmp23_;
							GMenuModel* _tmp24_;
							GMenuModel* _tmp25_;
							gint sub_items = 0;
							GMenuModel* _tmp26_;
							gint _tmp27_;
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
							if (!_tmp18_) {
#line 4785 "AppWindow.c"
								gint _tmp19_;
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
								_tmp19_ = j;
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
								j = _tmp19_ + 1;
#line 4791 "AppWindow.c"
							}
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp18_ = FALSE;
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp20_ = j;
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp21_ = model_items;
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
							if (!(_tmp20_ < _tmp21_)) {
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
								break;
#line 4803 "AppWindow.c"
							}
#line 806 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp22_ = model;
#line 806 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp23_ = j;
#line 806 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp24_ = g_menu_model_get_item_link (_tmp22_, _tmp23_, G_MENU_LINK_SECTION);
#line 806 "/home/jens/Source/shotwell/src/AppWindow.vala"
							subsection = _tmp24_;
#line 808 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp25_ = subsection;
#line 808 "/home/jens/Source/shotwell/src/AppWindow.vala"
							if (_tmp25_ == NULL) {
#line 809 "/home/jens/Source/shotwell/src/AppWindow.vala"
								_g_object_unref0 (subsection);
#line 809 "/home/jens/Source/shotwell/src/AppWindow.vala"
								continue;
#line 4821 "AppWindow.c"
							}
#line 812 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp26_ = subsection;
#line 812 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_tmp27_ = g_menu_model_get_n_items (_tmp26_);
#line 812 "/home/jens/Source/shotwell/src/AppWindow.vala"
							sub_items = _tmp27_;
#line 4829 "AppWindow.c"
							{
								gint k = 0;
#line 813 "/home/jens/Source/shotwell/src/AppWindow.vala"
								k = 0;
#line 4834 "AppWindow.c"
								{
									gboolean _tmp28_ = FALSE;
#line 813 "/home/jens/Source/shotwell/src/AppWindow.vala"
									_tmp28_ = TRUE;
#line 813 "/home/jens/Source/shotwell/src/AppWindow.vala"
									while (TRUE) {
#line 4841 "AppWindow.c"
										gint _tmp30_;
										gint _tmp31_;
										GMenuAttributeIter* it = NULL;
										GMenuModel* _tmp32_;
										gint _tmp33_;
										GMenuAttributeIter* _tmp34_;
#line 813 "/home/jens/Source/shotwell/src/AppWindow.vala"
										if (!_tmp28_) {
#line 4850 "AppWindow.c"
											gint _tmp29_;
#line 813 "/home/jens/Source/shotwell/src/AppWindow.vala"
											_tmp29_ = k;
#line 813 "/home/jens/Source/shotwell/src/AppWindow.vala"
											k = _tmp29_ + 1;
#line 4856 "AppWindow.c"
										}
#line 813 "/home/jens/Source/shotwell/src/AppWindow.vala"
										_tmp28_ = FALSE;
#line 813 "/home/jens/Source/shotwell/src/AppWindow.vala"
										_tmp30_ = k;
#line 813 "/home/jens/Source/shotwell/src/AppWindow.vala"
										_tmp31_ = sub_items;
#line 813 "/home/jens/Source/shotwell/src/AppWindow.vala"
										if (!(_tmp30_ < _tmp31_)) {
#line 813 "/home/jens/Source/shotwell/src/AppWindow.vala"
											break;
#line 4868 "AppWindow.c"
										}
#line 814 "/home/jens/Source/shotwell/src/AppWindow.vala"
										_tmp32_ = subsection;
#line 814 "/home/jens/Source/shotwell/src/AppWindow.vala"
										_tmp33_ = k;
#line 814 "/home/jens/Source/shotwell/src/AppWindow.vala"
										_tmp34_ = g_menu_model_iterate_item_attributes (_tmp32_, _tmp33_);
#line 814 "/home/jens/Source/shotwell/src/AppWindow.vala"
										it = _tmp34_;
#line 815 "/home/jens/Source/shotwell/src/AppWindow.vala"
										while (TRUE) {
#line 4880 "AppWindow.c"
											GMenuAttributeIter* _tmp35_;
											gboolean _tmp36_;
											gboolean _tmp37_ = FALSE;
											gboolean _tmp38_ = FALSE;
											GMenuAttributeIter* _tmp39_;
											const gchar* _tmp40_;
#line 815 "/home/jens/Source/shotwell/src/AppWindow.vala"
											_tmp35_ = it;
#line 815 "/home/jens/Source/shotwell/src/AppWindow.vala"
											_tmp36_ = g_menu_attribute_iter_next (_tmp35_);
#line 815 "/home/jens/Source/shotwell/src/AppWindow.vala"
											if (!_tmp36_) {
#line 815 "/home/jens/Source/shotwell/src/AppWindow.vala"
												break;
#line 4895 "AppWindow.c"
											}
#line 816 "/home/jens/Source/shotwell/src/AppWindow.vala"
											_tmp39_ = it;
#line 816 "/home/jens/Source/shotwell/src/AppWindow.vala"
											_tmp40_ = g_menu_attribute_iter_get_name (_tmp39_);
#line 816 "/home/jens/Source/shotwell/src/AppWindow.vala"
											if (g_strcmp0 (_tmp40_, "id") == 0) {
#line 4903 "AppWindow.c"
												GMenuAttributeIter* _tmp41_;
												GVariant* _tmp42_;
												GVariant* _tmp43_;
												const gchar* _tmp44_;
												const gchar* _tmp45_;
#line 816 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp41_ = it;
#line 816 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp42_ = g_menu_attribute_iter_get_value (_tmp41_);
#line 816 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp43_ = _tmp42_;
#line 816 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp44_ = g_variant_get_string (_tmp43_, NULL);
#line 816 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp45_ = id;
#line 816 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp38_ = g_strcmp0 (_tmp44_, _tmp45_) == 0;
#line 816 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_g_variant_unref0 (_tmp43_);
#line 4923 "AppWindow.c"
											} else {
#line 816 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp38_ = FALSE;
#line 4927 "AppWindow.c"
											}
#line 816 "/home/jens/Source/shotwell/src/AppWindow.vala"
											if (_tmp38_) {
#line 816 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp37_ = TRUE;
#line 4933 "AppWindow.c"
											} else {
												gboolean _tmp46_ = FALSE;
												GMenuAttributeIter* _tmp47_;
												const gchar* _tmp48_;
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp47_ = it;
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp48_ = g_menu_attribute_iter_get_name (_tmp47_);
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
												if (g_strcmp0 (_tmp48_, "action") == 0) {
#line 4944 "AppWindow.c"
													GMenuAttributeIter* _tmp49_;
													GVariant* _tmp50_;
													GVariant* _tmp51_;
													const gchar* _tmp52_;
													const gchar* _tmp53_;
													gchar* _tmp54_;
													gchar* _tmp55_;
													gboolean _tmp56_;
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp49_ = it;
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp50_ = g_menu_attribute_iter_get_value (_tmp49_);
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp51_ = _tmp50_;
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp52_ = g_variant_get_string (_tmp51_, NULL);
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp53_ = id;
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp54_ = g_strconcat (".", _tmp53_, NULL);
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp55_ = _tmp54_;
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp56_ = g_str_has_suffix (_tmp52_, _tmp55_);
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp46_ = _tmp56_;
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_g_free0 (_tmp55_);
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_g_variant_unref0 (_tmp51_);
#line 4975 "AppWindow.c"
												} else {
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
													_tmp46_ = FALSE;
#line 4979 "AppWindow.c"
												}
#line 817 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp37_ = _tmp46_;
#line 4983 "AppWindow.c"
											}
#line 816 "/home/jens/Source/shotwell/src/AppWindow.vala"
											if (_tmp37_) {
#line 4987 "AppWindow.c"
												GMenu* md = NULL;
												GMenuModel* _tmp57_;
												GMenu* _tmp58_;
												GMenuItem* m = NULL;
												GMenuModel* _tmp59_;
												gint _tmp60_;
												GMenuItem* _tmp61_;
												GMenuItem* _tmp62_;
												const gchar* _tmp63_;
												GMenu* _tmp64_;
												gint _tmp65_;
												GMenu* _tmp66_;
												gint _tmp67_;
												GMenuItem* _tmp68_;
#line 818 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp57_ = subsection;
#line 818 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp58_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp57_, g_menu_get_type ()) ? ((GMenu*) _tmp57_) : NULL);
#line 818 "/home/jens/Source/shotwell/src/AppWindow.vala"
												md = _tmp58_;
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp59_ = subsection;
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp60_ = k;
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp61_ = g_menu_item_new_from_model (_tmp59_, _tmp60_);
#line 819 "/home/jens/Source/shotwell/src/AppWindow.vala"
												m = _tmp61_;
#line 820 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp62_ = m;
#line 820 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp63_ = new_label;
#line 820 "/home/jens/Source/shotwell/src/AppWindow.vala"
												g_menu_item_set_label (_tmp62_, _tmp63_);
#line 821 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp64_ = md;
#line 821 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp65_ = k;
#line 821 "/home/jens/Source/shotwell/src/AppWindow.vala"
												g_menu_remove (_tmp64_, _tmp65_);
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp66_ = md;
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp67_ = k;
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_tmp68_ = m;
#line 822 "/home/jens/Source/shotwell/src/AppWindow.vala"
												g_menu_insert_item (_tmp66_, _tmp67_, _tmp68_);
#line 824 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_g_object_unref0 (m);
#line 824 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_g_object_unref0 (md);
#line 824 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_g_object_unref0 (it);
#line 824 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_g_object_unref0 (subsection);
#line 824 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_g_object_unref0 (model);
#line 824 "/home/jens/Source/shotwell/src/AppWindow.vala"
												_g_object_unref0 (bar);
#line 824 "/home/jens/Source/shotwell/src/AppWindow.vala"
												return;
#line 5050 "AppWindow.c"
											}
										}
#line 813 "/home/jens/Source/shotwell/src/AppWindow.vala"
										_g_object_unref0 (it);
#line 5055 "AppWindow.c"
									}
								}
							}
#line 805 "/home/jens/Source/shotwell/src/AppWindow.vala"
							_g_object_unref0 (subsection);
#line 5061 "AppWindow.c"
						}
					}
				}
#line 798 "/home/jens/Source/shotwell/src/AppWindow.vala"
				_g_object_unref0 (model);
#line 5067 "AppWindow.c"
			}
		}
	}
#line 789 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (bar);
#line 5073 "AppWindow.c"
}


static gpointer _command_manager_ref0 (gpointer self) {
#line 835 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return self ? command_manager_ref (self) : NULL;
#line 5080 "AppWindow.c"
}


CommandManager* app_window_get_command_manager (void) {
	CommandManager* result = NULL;
	CommandManager* _tmp0_;
	CommandManager* _tmp1_;
#line 835 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_command_manager;
#line 835 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _command_manager_ref0 (_tmp0_);
#line 835 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp1_;
#line 835 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 5096 "AppWindow.c"
}


static void app_window_on_command_manager_altered (AppWindow* self) {
#line 838 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 839 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_decorate_undo_action (self);
#line 840 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_decorate_redo_action (self);
#line 5107 "AppWindow.c"
}


static void app_window_decorate_command_manager_action (AppWindow* self, const gchar* name, const gchar* prefix, const gchar* default_explanation, CommandDescription* desc) {
	GSimpleAction* action = NULL;
	const gchar* _tmp0_;
	GAction* _tmp1_;
	GSimpleAction* _tmp2_;
	GSimpleAction* _tmp3_;
	gchar* label = NULL;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	CommandDescription* _tmp6_;
	const gchar* _tmp18_;
	const gchar* _tmp19_;
#line 843 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 843 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (name != NULL);
#line 843 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (prefix != NULL);
#line 843 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (default_explanation != NULL);
#line 843 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail ((desc == NULL) || IS_COMMAND_DESCRIPTION (desc));
#line 845 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = name;
#line 845 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = app_window_get_common_action (self, _tmp0_);
#line 845 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp1_) : NULL;
#line 845 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_ == NULL) {
#line 845 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp1_);
#line 5143 "AppWindow.c"
	}
#line 845 "/home/jens/Source/shotwell/src/AppWindow.vala"
	action = _tmp2_;
#line 846 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = action;
#line 846 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp3_ == NULL) {
#line 847 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (action);
#line 847 "/home/jens/Source/shotwell/src/AppWindow.vala"
		return;
#line 5155 "AppWindow.c"
	}
#line 850 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp4_ = prefix;
#line 850 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 850 "/home/jens/Source/shotwell/src/AppWindow.vala"
	label = _tmp5_;
#line 852 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = desc;
#line 852 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp6_ != NULL) {
#line 5167 "AppWindow.c"
		const gchar* _tmp7_;
		CommandDescription* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		GSimpleAction* _tmp14_;
#line 853 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp7_ = label;
#line 853 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp8_ = desc;
#line 853 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp9_ = command_description_get_name (_tmp8_);
#line 853 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp10_ = _tmp9_;
#line 853 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp11_ = g_strconcat (" ", _tmp10_, NULL);
#line 853 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp12_ = _tmp11_;
#line 853 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp13_ = g_strconcat (_tmp7_, _tmp12_, NULL);
#line 853 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (label);
#line 853 "/home/jens/Source/shotwell/src/AppWindow.vala"
		label = _tmp13_;
#line 853 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp12_);
#line 853 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (_tmp10_);
#line 854 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp14_ = action;
#line 854 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_simple_action_set_enabled (_tmp14_, TRUE);
#line 5202 "AppWindow.c"
	} else {
		const gchar* _tmp15_;
		gchar* _tmp16_;
		GSimpleAction* _tmp17_;
#line 856 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp15_ = prefix;
#line 856 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp16_ = g_strdup (_tmp15_);
#line 856 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_free0 (label);
#line 856 "/home/jens/Source/shotwell/src/AppWindow.vala"
		label = _tmp16_;
#line 857 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp17_ = action;
#line 857 "/home/jens/Source/shotwell/src/AppWindow.vala"
		g_simple_action_set_enabled (_tmp17_, FALSE);
#line 5219 "AppWindow.c"
	}
#line 859 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp18_ = name;
#line 859 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp19_ = label;
#line 859 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_update_menu_item_label (self, _tmp18_, _tmp19_);
#line 843 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_free0 (label);
#line 843 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (action);
#line 5231 "AppWindow.c"
}


void app_window_decorate_undo_action (AppWindow* self) {
	CommandManager* _tmp0_;
	CommandManager* _tmp1_;
	CommandDescription* _tmp2_;
	CommandDescription* _tmp3_;
#line 862 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 863 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_get_command_manager ();
#line 863 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 863 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = command_manager_get_undo_description (_tmp1_);
#line 863 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _tmp2_;
#line 863 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_decorate_command_manager_action (self, "CommonUndo", RESOURCES_UNDO_MENU, "", _tmp3_);
#line 863 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp3_);
#line 863 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_command_manager_unref0 (_tmp1_);
#line 5256 "AppWindow.c"
}


void app_window_decorate_redo_action (AppWindow* self) {
	CommandManager* _tmp0_;
	CommandManager* _tmp1_;
	CommandDescription* _tmp2_;
	CommandDescription* _tmp3_;
#line 867 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 868 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_get_command_manager ();
#line 868 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = _tmp0_;
#line 868 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = command_manager_get_redo_description (_tmp1_);
#line 868 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp3_ = _tmp2_;
#line 868 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_decorate_command_manager_action (self, "CommonRedo", RESOURCES_REDO_MENU, "", _tmp3_);
#line 868 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (_tmp3_);
#line 868 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_command_manager_unref0 (_tmp1_);
#line 5281 "AppWindow.c"
}


static void app_window_on_undo (AppWindow* self) {
	CommandManager* _tmp0_;
#line 872 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 873 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_command_manager;
#line 873 "/home/jens/Source/shotwell/src/AppWindow.vala"
	command_manager_undo (_tmp0_);
#line 5293 "AppWindow.c"
}


static void app_window_on_redo (AppWindow* self) {
	CommandManager* _tmp0_;
#line 876 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 877 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = app_window_command_manager;
#line 877 "/home/jens/Source/shotwell/src/AppWindow.vala"
	command_manager_redo (_tmp0_);
#line 5305 "AppWindow.c"
}


static void app_window_on_select_all (AppWindow* self) {
	Page* page = NULL;
	Page* _tmp0_;
	CheckerboardPage* _tmp1_;
	Page* _tmp2_;
#line 880 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 881 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 881 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_CHECKERBOARD_PAGE) ? ((CheckerboardPage*) _tmp0_) : NULL;
#line 881 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ == NULL) {
#line 881 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 5324 "AppWindow.c"
	}
#line 881 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PAGE, Page);
#line 882 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = page;
#line 882 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_ != NULL) {
#line 5332 "AppWindow.c"
		Page* _tmp3_;
		ViewCollection* _tmp4_;
		ViewCollection* _tmp5_;
#line 883 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = page;
#line 883 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = page_get_view (_tmp3_);
#line 883 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp4_;
#line 883 "/home/jens/Source/shotwell/src/AppWindow.vala"
		view_collection_select_all (_tmp5_);
#line 883 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp5_);
#line 5346 "AppWindow.c"
	}
#line 880 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (page);
#line 5350 "AppWindow.c"
}


static void app_window_on_select_none (AppWindow* self) {
	Page* page = NULL;
	Page* _tmp0_;
	CheckerboardPage* _tmp1_;
	Page* _tmp2_;
#line 886 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_if_fail (IS_APP_WINDOW (self));
#line 887 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 887 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_CHECKERBOARD_PAGE) ? ((CheckerboardPage*) _tmp0_) : NULL;
#line 887 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp1_ == NULL) {
#line 887 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 5369 "AppWindow.c"
	}
#line 887 "/home/jens/Source/shotwell/src/AppWindow.vala"
	page = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PAGE, Page);
#line 888 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = page;
#line 888 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (_tmp2_ != NULL) {
#line 5377 "AppWindow.c"
		Page* _tmp3_;
		ViewCollection* _tmp4_;
		ViewCollection* _tmp5_;
#line 889 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp3_ = page;
#line 889 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp4_ = page_get_view (_tmp3_);
#line 889 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_tmp5_ = _tmp4_;
#line 889 "/home/jens/Source/shotwell/src/AppWindow.vala"
		view_collection_unselect_all (_tmp5_);
#line 889 "/home/jens/Source/shotwell/src/AppWindow.vala"
		_data_collection_unref0 (_tmp5_);
#line 5391 "AppWindow.c"
	}
#line 886 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_g_object_unref0 (page);
#line 5395 "AppWindow.c"
}


static gboolean app_window_real_configure_event (GtkWidget* base, GdkEventConfigure* event) {
	AppWindow * self;
	gboolean result = FALSE;
	GdkWindow* _tmp0_;
	GdkWindowState _tmp1_;
	gboolean _tmp2_;
	GdkEventConfigure* _tmp5_;
	gboolean _tmp6_;
#line 892 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_APP_WINDOW, AppWindow);
#line 892 "/home/jens/Source/shotwell/src/AppWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 893 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp0_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 893 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp1_ = gdk_window_get_state (_tmp0_);
#line 893 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->maximized = _tmp1_ == GDK_WINDOW_STATE_MAXIMIZED;
#line 895 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp2_ = self->maximized;
#line 895 "/home/jens/Source/shotwell/src/AppWindow.vala"
	if (!_tmp2_) {
#line 5421 "AppWindow.c"
		gint _tmp3_ = 0;
		gint _tmp4_ = 0;
#line 896 "/home/jens/Source/shotwell/src/AppWindow.vala"
		gtk_window_get_size (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), &_tmp3_, &_tmp4_);
#line 896 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->dimensions.width = _tmp3_;
#line 896 "/home/jens/Source/shotwell/src/AppWindow.vala"
		self->dimensions.height = _tmp4_;
#line 5430 "AppWindow.c"
	}
#line 898 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp5_ = event;
#line 898 "/home/jens/Source/shotwell/src/AppWindow.vala"
	_tmp6_ = GTK_WIDGET_CLASS (app_window_parent_class)->configure_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow), gtk_widget_get_type (), GtkWidget), _tmp5_);
#line 898 "/home/jens/Source/shotwell/src/AppWindow.vala"
	result = _tmp6_;
#line 898 "/home/jens/Source/shotwell/src/AppWindow.vala"
	return result;
#line 5440 "AppWindow.c"
}


static void app_window_class_init (AppWindowClass * klass) {
#line 392 "/home/jens/Source/shotwell/src/AppWindow.vala"
	app_window_parent_class = g_type_class_peek_parent (klass);
#line 392 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((AppWindowClass *) klass)->on_fullscreen = (void (*) (AppWindow *)) app_window_real_on_fullscreen;
#line 392 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((AppWindowClass *) klass)->get_app_role = (gchar* (*) (AppWindow *)) app_window_real_get_app_role;
#line 392 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((AppWindowClass *) klass)->on_quit = (void (*) (AppWindow *)) app_window_real_on_quit;
#line 392 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->destroy = (void (*) (GtkWidget *)) app_window_real_destroy;
#line 392 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((AppWindowClass *) klass)->add_actions = (void (*) (AppWindow *)) app_window_real_add_actions;
#line 392 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((PageWindowClass *) klass)->switched_pages = (void (*) (PageWindow *, Page*, Page*)) app_window_real_switched_pages;
#line 392 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((AppWindowClass *) klass)->update_common_action_availability = (void (*) (AppWindow *, Page*, Page*)) app_window_real_update_common_action_availability;
#line 392 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((AppWindowClass *) klass)->update_common_actions = (void (*) (AppWindow *, Page*, gint, gint)) app_window_real_update_common_actions;
#line 392 "/home/jens/Source/shotwell/src/AppWindow.vala"
	((GtkWidgetClass *) klass)->configure_event = (gboolean (*) (GtkWidget *, GdkEventConfigure*)) app_window_real_configure_event;
#line 392 "/home/jens/Source/shotwell/src/AppWindow.vala"
	G_OBJECT_CLASS (klass)->finalize = app_window_finalize;
#line 5467 "AppWindow.c"
}


static void app_window_instance_init (AppWindow * self) {
#line 402 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->maximized = FALSE;
#line 404 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->pos_x = 0;
#line 405 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self->pos_y = 0;
#line 5478 "AppWindow.c"
}


static void app_window_finalize (GObject * obj) {
	AppWindow * self;
#line 392 "/home/jens/Source/shotwell/src/AppWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_APP_WINDOW, AppWindow);
#line 392 "/home/jens/Source/shotwell/src/AppWindow.vala"
	G_OBJECT_CLASS (app_window_parent_class)->finalize (obj);
#line 5488 "AppWindow.c"
}


GType app_window_get_type (void) {
	static volatile gsize app_window_type_id__volatile = 0;
	if (g_once_init_enter (&app_window_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AppWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) app_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AppWindow), 0, (GInstanceInitFunc) app_window_instance_init, NULL };
		GType app_window_type_id;
		app_window_type_id = g_type_register_static (TYPE_PAGE_WINDOW, "AppWindow", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&app_window_type_id__volatile, app_window_type_id);
	}
	return app_window_type_id__volatile;
}



